

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationAllowedActions of Str where subset-is * eq 'all'|'local_only'|'selected', 'WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationAllowedActions must be either "all", "local_only" or "selected"';

subset WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationEnabledRepositories of Str where subset-is * eq 'all'|'none'|'selected', 'WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationEnabledRepositories must be either "all", "none" or "selected"';

subset WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsRepositoryAllowedActions of Str where subset-is * eq 'all'|'local_only'|'selected', 'WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsRepositoryAllowedActions must be either "all", "local_only" or "selected"';


class WebService::GitHub::Actions::Permissions  {
    also does WebService::GitHub::Role;
    method disable-selected-repository-github-actions-organization(Str $org, Int(Str) $repository-id) {
        self.request("/orgs/$org/actions/permissions/repositories/$repository-id","DELETE")
    }

    method enable-selected-repository-github-actions-organization(Str $org, Int(Str) $repository-id) {
        self.request("/orgs/$org/actions/permissions/repositories/$repository-id","PUT")
    }

    method get-allowed-actions-organization(Str $org) {
        self.request("/orgs/$org/actions/permissions/selected-actions","GET")
    }

    method get-allowed-actions-repository(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/actions/permissions/selected-actions","GET")
    }

    method get-github-actions-permissions-organization(Str $org) {
        self.request("/orgs/$org/actions/permissions","GET")
    }

    method get-github-actions-permissions-repository(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/actions/permissions","GET")
    }

    method list-selected-repositories-enabled-github-actions-organization(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/actions/permissions/repositories","GET", :%data)
    }

    method set-allowed-actions-organization(Str $org, Bool :$verified-allowed!, Positional :$patterns-allowed!, Bool :$github-owned-allowed!) {
        my %data;
        %data<verified_allowed> = $verified-allowed;
        %data<patterns_allowed> = $patterns-allowed;
        %data<github_owned_allowed> = $github-owned-allowed;
        self.request("/orgs/$org/actions/permissions/selected-actions","PUT", :%data)
    }

    method set-allowed-actions-repository(Str $owner, Str $repo, Positional :$patterns-allowed!, Bool :$github-owned-allowed!, Bool :$verified-allowed!) {
        my %data;
        %data<patterns_allowed> = $patterns-allowed;
        %data<github_owned_allowed> = $github-owned-allowed;
        %data<verified_allowed> = $verified-allowed;
        self.request("/repos/$owner/$repo/actions/permissions/selected-actions","PUT", :%data)
    }

    method set-github-actions-permissions-organization(Str $org, WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationEnabledRepositories :$enabled-repositories!, WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsOrganizationAllowedActions :$allowed-actions) {
        my %data;
        %data<allowed_actions> = $allowed-actions if defined $allowed-actions;
        %data<enabled_repositories> = $enabled-repositories;
        self.request("/orgs/$org/actions/permissions","PUT", :%data)
    }

    method set-github-actions-permissions-repository(Str $owner, Str $repo, Bool :$enabled!, WebService::GitHub::Actions::Permissions::SetGithubActionsPermissionsRepositoryAllowedActions :$allowed-actions) {
        my %data;
        %data<enabled> = $enabled;
        %data<allowed_actions> = $allowed-actions if defined $allowed-actions;
        self.request("/repos/$owner/$repo/actions/permissions","PUT", :%data)
    }

    method set-selected-repositories-enabled-github-actions-organization(Str $org, Positional :$selected-repository-ids!) {
        my %data;
        %data<selected_repository_ids> = $selected-repository-ids;
        self.request("/orgs/$org/actions/permissions/repositories","PUT", :%data)
    }

}

