

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Actions::Secrets::CreateOrUpdateOrgSecretVisibility of Str where subset-is * eq 'all'|'private'|'selected', 'WebService::GitHub::Actions::Secrets::CreateOrUpdateOrgSecretVisibility must be either "all", "private" or "selected"';


class WebService::GitHub::Actions::Secrets  {
    also does WebService::GitHub::Role;
    method add-selected-repo-to-org-secret(Str $org, Str $secret-name, Int(Str) $repository-id) {
        self.request("/orgs/$org/actions/secrets/$secret-name/repositories/$repository-id","PUT")
    }

    method create-or-update-environment-secret(Int(Str) $repository-id, Str $environment-name, Str $secret-name, Str :$key-id, Str :$encrypted-value) {
        my %data;
        %data<key_id> = $key-id if defined $key-id;
        %data<encrypted_value> = $encrypted-value if defined $encrypted-value;
        self.request("/repositories/$repository-id/environments/$environment-name/secrets/$secret-name","PUT", :%data)
    }

    method create-or-update-org-secret(Str $org, Str $secret-name, Str :$encrypted-value, Positional :$selected-repository-ids, Str :$key-id, WebService::GitHub::Actions::Secrets::CreateOrUpdateOrgSecretVisibility :$visibility) {
        my %data;
        %data<encrypted_value> = $encrypted-value if defined $encrypted-value;
        %data<selected_repository_ids> = $selected-repository-ids if defined $selected-repository-ids;
        %data<key_id> = $key-id if defined $key-id;
        %data<visibility> = $visibility if defined $visibility;
        self.request("/orgs/$org/actions/secrets/$secret-name","PUT", :%data)
    }

    method create-or-update-repo-secret(Str $owner, Str $repo, Str $secret-name, Str :$encrypted-value, Str :$key-id) {
        my %data;
        %data<encrypted_value> = $encrypted-value if defined $encrypted-value;
        %data<key_id> = $key-id if defined $key-id;
        self.request("/repos/$owner/$repo/actions/secrets/$secret-name","PUT", :%data)
    }

    method delete-environment-secret(Int(Str) $repository-id, Str $environment-name, Str $secret-name) {
        self.request("/repositories/$repository-id/environments/$environment-name/secrets/$secret-name","DELETE")
    }

    method delete-org-secret(Str $org, Str $secret-name) {
        self.request("/orgs/$org/actions/secrets/$secret-name","DELETE")
    }

    method delete-repo-secret(Str $owner, Str $repo, Str $secret-name) {
        self.request("/repos/$owner/$repo/actions/secrets/$secret-name","DELETE")
    }

    method get-environment-public-key(Int(Str) $repository-id, Str $environment-name) {
        self.request("/repositories/$repository-id/environments/$environment-name/secrets/public-key","GET")
    }

    method get-environment-secret(Int(Str) $repository-id, Str $environment-name, Str $secret-name) {
        self.request("/repositories/$repository-id/environments/$environment-name/secrets/$secret-name","GET")
    }

    method get-org-public-key(Str $org) {
        self.request("/orgs/$org/actions/secrets/public-key","GET")
    }

    method get-org-secret(Str $org, Str $secret-name) {
        self.request("/orgs/$org/actions/secrets/$secret-name","GET")
    }

    method get-repo-public-key(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/actions/secrets/public-key","GET")
    }

    method get-repo-secret(Str $owner, Str $repo, Str $secret-name) {
        self.request("/repos/$owner/$repo/actions/secrets/$secret-name","GET")
    }

    method list-environment-secrets(Int(Str) $repository-id, Str $environment-name, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repositories/$repository-id/environments/$environment-name/secrets","GET", :%data)
    }

    method list-org-secrets(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/actions/secrets","GET", :%data)
    }

    method list-repo-secrets(Str $owner, Str $repo, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/actions/secrets","GET", :%data)
    }

    method list-selected-repos-for-org-secret(Str $org, Str $secret-name, Int(Str) :$page, Int(Str) :$per-page) {
        my %data;
        %data<page> = $page if defined $page;
        %data<per_page> = $per-page if defined $per-page;
        self.request("/orgs/$org/actions/secrets/$secret-name/repositories","GET", :%data)
    }

    method remove-selected-repo-from-org-secret(Str $org, Str $secret-name, Int(Str) $repository-id) {
        self.request("/orgs/$org/actions/secrets/$secret-name/repositories/$repository-id","DELETE")
    }

    method set-selected-repos-for-org-secret(Str $org, Str $secret-name, Positional :$selected-repository-ids) {
        my %data;
        %data<selected_repository_ids> = $selected-repository-ids if defined $selected-repository-ids;
        self.request("/orgs/$org/actions/secrets/$secret-name/repositories","PUT", :%data)
    }

}

