

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsForRepoStatus of Str where subset-is * eq 'completed'|'action_required'|'cancelled'|'failure'|'neutral'|'skipped'|'stale'|'success'|'timed_out'|'in_progress'|'queued'|'requested'|'waiting', 'WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsForRepoStatus must be either "completed", "action_required", "cancelled", "failure", "neutral", "skipped", "stale", "success", "timed_out", "in_progress", "queued", "requested" or "waiting"';

subset WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsStatus of Str where subset-is * eq 'completed'|'action_required'|'cancelled'|'failure'|'neutral'|'skipped'|'stale'|'success'|'timed_out'|'in_progress'|'queued'|'requested'|'waiting', 'WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsStatus must be either "completed", "action_required", "cancelled", "failure", "neutral", "skipped", "stale", "success", "timed_out", "in_progress", "queued", "requested" or "waiting"';

subset WebService::GitHub::Actions::WorkflowRuns::ReviewPendingDeploymentsForRunState of Str where subset-is * eq 'approved'|'rejected', 'WebService::GitHub::Actions::WorkflowRuns::ReviewPendingDeploymentsForRunState must be either "approved" or "rejected"';


class WebService::GitHub::Actions::WorkflowRuns  {
    also does WebService::GitHub::Role;
    method cancel-workflow-run(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/cancel","POST")
    }

    method delete-workflow-run(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id","DELETE")
    }

    method delete-workflow-run-logs(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/logs","DELETE")
    }

    method download-workflow-run-logs(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/logs","GET")
    }

    method get-pending-deployments-for-run(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/pending_deployments","GET")
    }

    method get-reviews-for-run(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/approvals","GET")
    }

    method get-workflow-run(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id","GET")
    }

    method get-workflow-run-usage(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/timing","GET")
    }

    method list-workflow-runs(Str $owner, Str $repo, Any $workflow-id, Str :$actor, Str :$branch, Str :$event, WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsStatus :$status, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<actor> = $actor if defined $actor;
        %data<branch> = $branch if defined $branch;
        %data<event> = $event if defined $event;
        %data<status> = $status if defined $status;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/actions/workflows/$workflow-id/runs","GET", :%data)
    }

    method list-workflow-runs-for-repo(Str $owner, Str $repo, Str :$actor, Str :$branch, Str :$event, WebService::GitHub::Actions::WorkflowRuns::ListWorkflowRunsForRepoStatus :$status, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<actor> = $actor if defined $actor;
        %data<branch> = $branch if defined $branch;
        %data<event> = $event if defined $event;
        %data<status> = $status if defined $status;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/actions/runs","GET", :%data)
    }

    method re-run-workflow(Str $owner, Str $repo, Int(Str) $run-id) {
        self.request("/repos/$owner/$repo/actions/runs/$run-id/rerun","POST")
    }

    method review-pending-deployments-for-run(Str $owner, Str $repo, Int(Str) $run-id, Positional :$environment-ids!, Str :$comment!, WebService::GitHub::Actions::WorkflowRuns::ReviewPendingDeploymentsForRunState :$state!) {
        my %data;
        %data<environment_ids> = $environment-ids;
        %data<comment> = $comment;
        %data<state> = $state;
        self.request("/repos/$owner/$repo/actions/runs/$run-id/pending_deployments","POST", :%data)
    }

}

