

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Checks::Runs::CreateConclusion of Str where subset-is * eq 'action_required'|'cancelled'|'failure'|'neutral'|'success'|'skipped'|'stale'|'timed_out', 'WebService::GitHub::Checks::Runs::CreateConclusion must be either "action_required", "cancelled", "failure", "neutral", "success", "skipped", "stale" or "timed_out"';

subset WebService::GitHub::Checks::Runs::CreateStatus of Str where subset-is * eq 'queued'|'in_progress'|'completed', 'WebService::GitHub::Checks::Runs::CreateStatus must be either "queued", "in_progress" or "completed"';

subset WebService::GitHub::Checks::Runs::ListForRefFilter of Str where subset-is * eq 'latest'|'all', 'WebService::GitHub::Checks::Runs::ListForRefFilter must be either "latest" or "all"';

subset WebService::GitHub::Checks::Runs::ListForRefStatus of Str where subset-is * eq 'queued'|'in_progress'|'completed', 'WebService::GitHub::Checks::Runs::ListForRefStatus must be either "queued", "in_progress" or "completed"';

subset WebService::GitHub::Checks::Runs::ListForSuiteFilter of Str where subset-is * eq 'latest'|'all', 'WebService::GitHub::Checks::Runs::ListForSuiteFilter must be either "latest" or "all"';

subset WebService::GitHub::Checks::Runs::ListForSuiteStatus of Str where subset-is * eq 'queued'|'in_progress'|'completed', 'WebService::GitHub::Checks::Runs::ListForSuiteStatus must be either "queued", "in_progress" or "completed"';

subset WebService::GitHub::Checks::Runs::UpdateConclusion of Str where subset-is * eq 'action_required'|'cancelled'|'failure'|'neutral'|'success'|'skipped'|'stale'|'timed_out', 'WebService::GitHub::Checks::Runs::UpdateConclusion must be either "action_required", "cancelled", "failure", "neutral", "success", "skipped", "stale" or "timed_out"';

subset WebService::GitHub::Checks::Runs::UpdateStatus of Str where subset-is * eq 'queued'|'in_progress'|'completed', 'WebService::GitHub::Checks::Runs::UpdateStatus must be either "queued", "in_progress" or "completed"';


class WebService::GitHub::Checks::Runs  {
    also does WebService::GitHub::Role;
    method create(Str $owner, Str $repo, Str :$head-sha!, Str :$name!, Str :$external-id, Str :$completed-at, Str :$started-at, Str :$details-url, Positional :$actions, WebService::GitHub::Checks::Runs::CreateStatus :$status, WebService::GitHub::Checks::Runs::CreateConclusion :$conclusion, Associative :$output) {
        my %data;
        %data<external_id> = $external-id if defined $external-id;
        %data<completed_at> = $completed-at if defined $completed-at;
        %data<head_sha> = $head-sha;
        %data<started_at> = $started-at if defined $started-at;
        %data<details_url> = $details-url if defined $details-url;
        %data<actions> = $actions if defined $actions;
        %data<status> = $status if defined $status;
        %data<conclusion> = $conclusion if defined $conclusion;
        %data<name> = $name;
        %data<output> = $output if defined $output;
        self.request("/repos/$owner/$repo/check-runs","POST", :%data)
    }

    method get(Str $owner, Str $repo, Int(Str) $check-run-id) {
        self.request("/repos/$owner/$repo/check-runs/$check-run-id","GET")
    }

    method list-annotations(Str $owner, Str $repo, Int(Str) $check-run-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/check-runs/$check-run-id/annotations","GET", :%data)
    }

    method list-for-ref(Str $owner, Str $repo, Str $ref, Str :$check-name, WebService::GitHub::Checks::Runs::ListForRefStatus :$status, WebService::GitHub::Checks::Runs::ListForRefFilter :$filter, Int(Str) :$per-page, Int(Str) :$page, Int(Str) :$app-id) {
        my %data;
        %data<check_name> = $check-name if defined $check-name;
        %data<status> = $status if defined $status;
        %data<filter> = $filter if defined $filter;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        %data<app_id> = $app-id if defined $app-id;
        self.request("/repos/$owner/$repo/commits/$ref/check-runs","GET", :%data)
    }

    method list-for-suite(Str $owner, Str $repo, Int(Str) $check-suite-id, Str :$check-name, WebService::GitHub::Checks::Runs::ListForSuiteStatus :$status, WebService::GitHub::Checks::Runs::ListForSuiteFilter :$filter, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<check_name> = $check-name if defined $check-name;
        %data<status> = $status if defined $status;
        %data<filter> = $filter if defined $filter;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/check-suites/$check-suite-id/check-runs","GET", :%data)
    }

    method update(Str $owner, Str $repo, Int(Str) $check-run-id, Str :$details-url, Str :$completed-at, Str :$name, WebService::GitHub::Checks::Runs::UpdateConclusion :$conclusion, Str :$started-at, WebService::GitHub::Checks::Runs::UpdateStatus :$status, Associative :$output, Str :$external-id, Positional :$actions) {
        my %data;
        %data<details_url> = $details-url if defined $details-url;
        %data<completed_at> = $completed-at if defined $completed-at;
        %data<name> = $name if defined $name;
        %data<conclusion> = $conclusion if defined $conclusion;
        %data<started_at> = $started-at if defined $started-at;
        %data<status> = $status if defined $status;
        %data<output> = $output if defined $output;
        %data<external_id> = $external-id if defined $external-id;
        %data<actions> = $actions if defined $actions;
        self.request("/repos/$owner/$repo/check-runs/$check-run-id","PATCH", :%data)
    }

}

