

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::CodeScanning::ListAlertsForRepoState of Str where subset-is * eq 'open'|'closed'|'dismissed'|'fixed', 'WebService::GitHub::CodeScanning::ListAlertsForRepoState must be either "open", "closed", "dismissed" or "fixed"';

subset WebService::GitHub::CodeScanning::UpdateAlertState of Str where subset-is * eq 'open'|'dismissed', 'WebService::GitHub::CodeScanning::UpdateAlertState must be either "open" or "dismissed"';


class WebService::GitHub::CodeScanning  {
    also does WebService::GitHub::Role;
    method delete-analysis(Str $owner, Str $repo, Int(Str) $analysis-id, Str :$confirm-delete) {
        my %data;
        %data<confirm_delete> = $confirm-delete if defined $confirm-delete;
        self.request("/repos/$owner/$repo/code-scanning/analyses/$analysis-id","DELETE", :%data)
    }

    method get-alert(Str $owner, Str $repo, Int(Str) $alert-number) {
        self.request("/repos/$owner/$repo/code-scanning/alerts/$alert-number","GET")
    }

    method get-analysis(Str $owner, Str $repo, Int(Str) $analysis-id) {
        self.request("/repos/$owner/$repo/code-scanning/analyses/$analysis-id","GET")
    }

    method get-sarif(Str $owner, Str $repo, Str $sarif-id) {
        self.request("/repos/$owner/$repo/code-scanning/sarifs/$sarif-id","GET")
    }

    method list-alerts-for-repo(Str $owner, Str $repo, Str :$tool-name, Str :$tool-guid, Int(Str) :$page, Int(Str) :$per-page, Str :$ref, WebService::GitHub::CodeScanning::ListAlertsForRepoState :$state) {
        my %data;
        %data<tool_name> = $tool-name if defined $tool-name;
        %data<tool_guid> = $tool-guid if defined $tool-guid;
        %data<page> = $page if defined $page;
        %data<per_page> = $per-page if defined $per-page;
        %data<ref> = $ref if defined $ref;
        %data<state> = $state if defined $state;
        self.request("/repos/$owner/$repo/code-scanning/alerts","GET", :%data)
    }

    method list-alerts-instances(Str $owner, Str $repo, Int(Str) $alert-number, Int(Str) :$page, Int(Str) :$per-page, Str :$ref) {
        my %data;
        %data<page> = $page if defined $page;
        %data<per_page> = $per-page if defined $per-page;
        %data<ref> = $ref if defined $ref;
        self.request("/repos/$owner/$repo/code-scanning/alerts/$alert-number/instances","GET", :%data)
    }

    method list-recent-analyses(Str $owner, Str $repo, Str :$tool-name, Str :$tool-guid, Int(Str) :$page, Int(Str) :$per-page, Str :$ref, Str :$sarif-id) {
        my %data;
        %data<tool_name> = $tool-name if defined $tool-name;
        %data<tool_guid> = $tool-guid if defined $tool-guid;
        %data<page> = $page if defined $page;
        %data<per_page> = $per-page if defined $per-page;
        %data<ref> = $ref if defined $ref;
        %data<sarif_id> = $sarif-id if defined $sarif-id;
        self.request("/repos/$owner/$repo/code-scanning/analyses","GET", :%data)
    }

    method update-alert(Str $owner, Str $repo, Int(Str) $alert-number, WebService::GitHub::CodeScanning::UpdateAlertState :$state!, Str :$dismissed-reason) {
        my %data;
        %data<state> = $state;
        %data<dismissed_reason> = $dismissed-reason if defined $dismissed-reason;
        self.request("/repos/$owner/$repo/code-scanning/alerts/$alert-number","PATCH", :%data)
    }

    method upload-sarif(Str $owner, Str $repo, Str :$ref!, Str :$sarif!, Str :$commit-sha!, Str :$tool-name, Str :$started-at, Str :$checkout-uri) {
        my %data;
        %data<tool_name> = $tool-name if defined $tool-name;
        %data<started_at> = $started-at if defined $started-at;
        %data<ref> = $ref;
        %data<checkout_uri> = $checkout-uri if defined $checkout-uri;
        %data<sarif> = $sarif;
        %data<commit_sha> = $commit-sha;
        self.request("/repos/$owner/$repo/code-scanning/sarifs","POST", :%data)
    }

}

