

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::EnterpriseAdmin::Actions::CreateSelfHostedRunnerGroupForEnterpriseVisibility of Str where subset-is * eq 'selected'|'all', 'WebService::GitHub::EnterpriseAdmin::Actions::CreateSelfHostedRunnerGroupForEnterpriseVisibility must be either "selected" or "all"';

subset WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseAllowedActions of Str where subset-is * eq 'all'|'local_only'|'selected', 'WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseAllowedActions must be either "all", "local_only" or "selected"';

subset WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseEnabledOrganizations of Str where subset-is * eq 'all'|'none'|'selected', 'WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseEnabledOrganizations must be either "all", "none" or "selected"';

subset WebService::GitHub::EnterpriseAdmin::Actions::UpdateSelfHostedRunnerGroupForEnterpriseVisibility of Str where subset-is * eq 'selected'|'all', 'WebService::GitHub::EnterpriseAdmin::Actions::UpdateSelfHostedRunnerGroupForEnterpriseVisibility must be either "selected" or "all"';


class WebService::GitHub::EnterpriseAdmin::Actions  {
    also does WebService::GitHub::Role;
    method add-org-access-to-self-hosted-runner-group-in-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) $org-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/organizations/$org-id","PUT")
    }

    method add-self-hosted-runner-to-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) $runner-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/runners/$runner-id","PUT")
    }

    method create-registration-token-for-enterprise(Str $enterprise) {
        self.request("/enterprises/$enterprise/actions/runners/registration-token","POST")
    }

    method create-remove-token-for-enterprise(Str $enterprise) {
        self.request("/enterprises/$enterprise/actions/runners/remove-token","POST")
    }

    method create-self-hosted-runner-group-for-enterprise(Str $enterprise, Str :$name!, Positional :$selected-organization-ids, WebService::GitHub::EnterpriseAdmin::Actions::CreateSelfHostedRunnerGroupForEnterpriseVisibility :$visibility, Positional :$runners) {
        my %data;
        %data<selected_organization_ids> = $selected-organization-ids if defined $selected-organization-ids;
        %data<visibility> = $visibility if defined $visibility;
        %data<runners> = $runners if defined $runners;
        %data<name> = $name;
        self.request("/enterprises/$enterprise/actions/runner-groups","POST", :%data)
    }

    method delete-self-hosted-runner-from-enterprise(Str $enterprise, Int(Str) $runner-id) {
        self.request("/enterprises/$enterprise/actions/runners/$runner-id","DELETE")
    }

    method delete-self-hosted-runner-group-from-enterprise(Str $enterprise, Int(Str) $runner-group-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id","DELETE")
    }

    method disable-selected-organization-github-actions-enterprise(Str $enterprise, Int(Str) $org-id) {
        self.request("/enterprises/$enterprise/actions/permissions/organizations/$org-id","DELETE")
    }

    method enable-selected-organization-github-actions-enterprise(Str $enterprise, Int(Str) $org-id) {
        self.request("/enterprises/$enterprise/actions/permissions/organizations/$org-id","PUT")
    }

    method get-allowed-actions-enterprise(Str $enterprise) {
        self.request("/enterprises/$enterprise/actions/permissions/selected-actions","GET")
    }

    method get-github-actions-permissions-enterprise(Str $enterprise) {
        self.request("/enterprises/$enterprise/actions/permissions","GET")
    }

    method get-self-hosted-runner-for-enterprise(Str $enterprise, Int(Str) $runner-id) {
        self.request("/enterprises/$enterprise/actions/runners/$runner-id","GET")
    }

    method get-self-hosted-runner-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id","GET")
    }

    method list-org-access-to-self-hosted-runner-group-in-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/organizations","GET", :%data)
    }

    method list-runner-applications-for-enterprise(Str $enterprise) {
        self.request("/enterprises/$enterprise/actions/runners/downloads","GET")
    }

    method list-selected-organizations-enabled-github-actions-enterprise(Str $enterprise, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/enterprises/$enterprise/actions/permissions/organizations","GET", :%data)
    }

    method list-self-hosted-runner-groups-for-enterprise(Str $enterprise, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/enterprises/$enterprise/actions/runner-groups","GET", :%data)
    }

    method list-self-hosted-runners-for-enterprise(Str $enterprise, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/enterprises/$enterprise/actions/runners","GET", :%data)
    }

    method list-self-hosted-runners-in-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/runners","GET", :%data)
    }

    method remove-org-access-to-self-hosted-runner-group-in-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) $org-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/organizations/$org-id","DELETE")
    }

    method remove-self-hosted-runner-from-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id, Int(Str) $runner-id) {
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/runners/$runner-id","DELETE")
    }

    method set-allowed-actions-enterprise(Str $enterprise, Bool :$verified-allowed!, Positional :$patterns-allowed!, Bool :$github-owned-allowed!) {
        my %data;
        %data<verified_allowed> = $verified-allowed;
        %data<patterns_allowed> = $patterns-allowed;
        %data<github_owned_allowed> = $github-owned-allowed;
        self.request("/enterprises/$enterprise/actions/permissions/selected-actions","PUT", :%data)
    }

    method set-github-actions-permissions-enterprise(Str $enterprise, WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseEnabledOrganizations :$enabled-organizations!, WebService::GitHub::EnterpriseAdmin::Actions::SetGithubActionsPermissionsEnterpriseAllowedActions :$allowed-actions) {
        my %data;
        %data<allowed_actions> = $allowed-actions if defined $allowed-actions;
        %data<enabled_organizations> = $enabled-organizations;
        self.request("/enterprises/$enterprise/actions/permissions","PUT", :%data)
    }

    method set-org-access-to-self-hosted-runner-group-in-enterprise(Str $enterprise, Int(Str) $runner-group-id, Positional :$selected-organization-ids!) {
        my %data;
        %data<selected_organization_ids> = $selected-organization-ids;
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/organizations","PUT", :%data)
    }

    method set-selected-organizations-enabled-github-actions-enterprise(Str $enterprise, Positional :$selected-organization-ids!) {
        my %data;
        %data<selected_organization_ids> = $selected-organization-ids;
        self.request("/enterprises/$enterprise/actions/permissions/organizations","PUT", :%data)
    }

    method set-self-hosted-runners-in-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id, Positional :$runners!) {
        my %data;
        %data<runners> = $runners;
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id/runners","PUT", :%data)
    }

    method update-self-hosted-runner-group-for-enterprise(Str $enterprise, Int(Str) $runner-group-id, Str :$name, WebService::GitHub::EnterpriseAdmin::Actions::UpdateSelfHostedRunnerGroupForEnterpriseVisibility :$visibility) {
        my %data;
        %data<name> = $name if defined $name;
        %data<visibility> = $visibility if defined $visibility;
        self.request("/enterprises/$enterprise/actions/runner-groups/$runner-group-id","PATCH", :%data)
    }

}

