


use WebService::GitHub::Role;

class WebService::GitHub::EnterpriseAdmin::Scim  {
    also does WebService::GitHub::Role;
    method delete-scim-group-from-enterprise(Str $enterprise, Str $scim-group-id) {
        self.request("/scim/v2/enterprises/$enterprise/Groups/$scim-group-id","DELETE")
    }

    method delete-user-from-enterprise(Str $enterprise, Str $scim-user-id) {
        self.request("/scim/v2/enterprises/$enterprise/Users/$scim-user-id","DELETE")
    }

    method get-provisioning-information-for-enterprise-group(Str $enterprise, Str $scim-group-id, Str :$excludedAttributes) {
        my %data;
        %data<excludedAttributes> = $excludedAttributes if defined $excludedAttributes;
        self.request("/scim/v2/enterprises/$enterprise/Groups/$scim-group-id","GET", :%data)
    }

    method get-provisioning-information-for-enterprise-user(Str $enterprise, Str $scim-user-id) {
        self.request("/scim/v2/enterprises/$enterprise/Users/$scim-user-id","GET")
    }

    method list-provisioned-groups-enterprise(Str $enterprise, Int(Str) :$startIndex, Int(Str) :$count, Str :$filter, Str :$excludedAttributes) {
        my %data;
        %data<startIndex> = $startIndex if defined $startIndex;
        %data<count> = $count if defined $count;
        %data<filter> = $filter if defined $filter;
        %data<excludedAttributes> = $excludedAttributes if defined $excludedAttributes;
        self.request("/scim/v2/enterprises/$enterprise/Groups","GET", :%data)
    }

    method list-provisioned-identities-enterprise(Str $enterprise, Int(Str) :$startIndex, Int(Str) :$count, Str :$filter) {
        my %data;
        %data<startIndex> = $startIndex if defined $startIndex;
        %data<count> = $count if defined $count;
        %data<filter> = $filter if defined $filter;
        self.request("/scim/v2/enterprises/$enterprise/Users","GET", :%data)
    }

    method provision-and-invite-enterprise-group(Str $enterprise, Str :$displayName!, Positional :$schemas!, Positional :$members) {
        my %data;
        %data<displayName> = $displayName;
        %data<members> = $members if defined $members;
        %data<schemas> = $schemas;
        self.request("/scim/v2/enterprises/$enterprise/Groups","POST", :%data)
    }

    method provision-and-invite-enterprise-user(Str $enterprise, Str :$userName!, Associative :$name!, Positional :$schemas!, Positional :$emails!, Positional :$groups) {
        my %data;
        %data<userName> = $userName;
        %data<name> = $name;
        %data<schemas> = $schemas;
        %data<emails> = $emails;
        %data<groups> = $groups if defined $groups;
        self.request("/scim/v2/enterprises/$enterprise/Users","POST", :%data)
    }

    method set-information-for-provisioned-enterprise-group(Str $enterprise, Str $scim-group-id, Positional :$schemas!, Str :$displayName!, Positional :$members) {
        my %data;
        %data<members> = $members if defined $members;
        %data<schemas> = $schemas;
        %data<displayName> = $displayName;
        self.request("/scim/v2/enterprises/$enterprise/Groups/$scim-group-id","PUT", :%data)
    }

    method set-information-for-provisioned-enterprise-user(Str $enterprise, Str $scim-user-id, Associative :$name!, Positional :$schemas!, Positional :$emails!, Str :$userName!, Positional :$groups) {
        my %data;
        %data<name> = $name;
        %data<schemas> = $schemas;
        %data<groups> = $groups if defined $groups;
        %data<emails> = $emails;
        %data<userName> = $userName;
        self.request("/scim/v2/enterprises/$enterprise/Users/$scim-user-id","PUT", :%data)
    }

    method update-attribute-for-enterprise-group(Str $enterprise, Str $scim-group-id, Positional :$Operations!, Positional :$schemas!) {
        my %data;
        %data<Operations> = $Operations;
        %data<schemas> = $schemas;
        self.request("/scim/v2/enterprises/$enterprise/Groups/$scim-group-id","PATCH", :%data)
    }

    method update-attribute-for-enterprise-user(Str $enterprise, Str $scim-user-id, Positional :$schemas!, Positional :$Operations!) {
        my %data;
        %data<schemas> = $schemas;
        %data<Operations> = $Operations;
        self.request("/scim/v2/enterprises/$enterprise/Users/$scim-user-id","PATCH", :%data)
    }

}

