


use WebService::GitHub::Role;

class WebService::GitHub::Gists  {
    also does WebService::GitHub::Role;
    method check-is-starred(Str $gist-id) {
        self.request("/gists/$gist-id/star","GET")
    }

    method create(Associative :$files!, Str :$description, :$public) {
        my %data;
        %data<description> = $description if defined $description;
        %data<files> = $files;
        %data<public> = $public if defined $public;
        self.request("/gists","POST", :%data)
    }

    method delete(Str $gist-id) {
        self.request("/gists/$gist-id","DELETE")
    }

    method fork(Str $gist-id) {
        self.request("/gists/$gist-id/forks","POST")
    }

    method get(Str $gist-id) {
        self.request("/gists/$gist-id","GET")
    }

    method get-revision(Str $gist-id, Str $sha) {
        self.request("/gists/$gist-id/$sha","GET")
    }

    method list(Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/gists","GET", :%data)
    }

    method list-commits(Str $gist-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/gists/$gist-id/commits","GET", :%data)
    }

    method list-for-user(Str $username, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/users/$username/gists","GET", :%data)
    }

    method list-forks(Str $gist-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/gists/$gist-id/forks","GET", :%data)
    }

    method list-public(Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/gists/public","GET", :%data)
    }

    method list-starred(Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/gists/starred","GET", :%data)
    }

    method star(Str $gist-id) {
        self.request("/gists/$gist-id/star","PUT")
    }

    method unstar(Str $gist-id) {
        self.request("/gists/$gist-id/star","DELETE")
    }

    method update(Str $gist-id, Associative :$files, Str :$description) {
        my %data;
        %data<files> = $files if defined $files;
        %data<description> = $description if defined $description;
        self.request("/gists/$gist-id","PATCH", :%data)
    }

}

