

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Issues::ListDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Issues::ListDirection must be either "asc" or "desc"';

subset WebService::GitHub::Issues::ListFilter of Str where subset-is * eq 'assigned'|'created'|'mentioned'|'subscribed'|'repos'|'all', 'WebService::GitHub::Issues::ListFilter must be either "assigned", "created", "mentioned", "subscribed", "repos" or "all"';

subset WebService::GitHub::Issues::ListForAuthenticatedUserDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Issues::ListForAuthenticatedUserDirection must be either "asc" or "desc"';

subset WebService::GitHub::Issues::ListForAuthenticatedUserFilter of Str where subset-is * eq 'assigned'|'created'|'mentioned'|'subscribed'|'repos'|'all', 'WebService::GitHub::Issues::ListForAuthenticatedUserFilter must be either "assigned", "created", "mentioned", "subscribed", "repos" or "all"';

subset WebService::GitHub::Issues::ListForAuthenticatedUserSort of Str where subset-is * eq 'created'|'updated'|'comments', 'WebService::GitHub::Issues::ListForAuthenticatedUserSort must be either "created", "updated" or "comments"';

subset WebService::GitHub::Issues::ListForAuthenticatedUserState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Issues::ListForAuthenticatedUserState must be either "open", "closed" or "all"';

subset WebService::GitHub::Issues::ListForOrgDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Issues::ListForOrgDirection must be either "asc" or "desc"';

subset WebService::GitHub::Issues::ListForOrgFilter of Str where subset-is * eq 'assigned'|'created'|'mentioned'|'subscribed'|'repos'|'all', 'WebService::GitHub::Issues::ListForOrgFilter must be either "assigned", "created", "mentioned", "subscribed", "repos" or "all"';

subset WebService::GitHub::Issues::ListForOrgSort of Str where subset-is * eq 'created'|'updated'|'comments', 'WebService::GitHub::Issues::ListForOrgSort must be either "created", "updated" or "comments"';

subset WebService::GitHub::Issues::ListForOrgState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Issues::ListForOrgState must be either "open", "closed" or "all"';

subset WebService::GitHub::Issues::ListForRepoDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Issues::ListForRepoDirection must be either "asc" or "desc"';

subset WebService::GitHub::Issues::ListForRepoSort of Str where subset-is * eq 'created'|'updated'|'comments', 'WebService::GitHub::Issues::ListForRepoSort must be either "created", "updated" or "comments"';

subset WebService::GitHub::Issues::ListForRepoState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Issues::ListForRepoState must be either "open", "closed" or "all"';

subset WebService::GitHub::Issues::ListSort of Str where subset-is * eq 'created'|'updated'|'comments', 'WebService::GitHub::Issues::ListSort must be either "created", "updated" or "comments"';

subset WebService::GitHub::Issues::ListState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Issues::ListState must be either "open", "closed" or "all"';

subset WebService::GitHub::Issues::LockLockReason of Str where subset-is * eq 'off-topic'|'too heated'|'resolved'|'spam', 'WebService::GitHub::Issues::LockLockReason must be either "off-topic", "too heated", "resolved" or "spam"';

subset WebService::GitHub::Issues::UpdateState of Str where subset-is * eq 'open'|'closed', 'WebService::GitHub::Issues::UpdateState must be either "open" or "closed"';


class WebService::GitHub::Issues  {
    also does WebService::GitHub::Role;
    method create(Str $owner, Str $repo, :$title!, Positional :$labels, Str :$assignee, Str :$body, Positional :$assignees, :$milestone) {
        my %data;
        %data<labels> = $labels if defined $labels;
        %data<assignee> = $assignee if defined $assignee;
        %data<body> = $body if defined $body;
        %data<assignees> = $assignees if defined $assignees;
        %data<title> = $title;
        %data<milestone> = $milestone if defined $milestone;
        self.request("/repos/$owner/$repo/issues","POST", :%data)
    }

    method get(Str $owner, Str $repo, Int(Str) $issue-number) {
        self.request("/repos/$owner/$repo/issues/$issue-number","GET")
    }

    method list(WebService::GitHub::Issues::ListFilter :$filter, WebService::GitHub::Issues::ListState :$state, Str :$labels, WebService::GitHub::Issues::ListSort :$sort, WebService::GitHub::Issues::ListDirection :$direction, Str :$since, Bool :$collab, Bool :$orgs, Bool :$owned, Bool :$pulls, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<filter> = $filter if defined $filter;
        %data<state> = $state if defined $state;
        %data<labels> = $labels if defined $labels;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<collab> = $collab if defined $collab;
        %data<orgs> = $orgs if defined $orgs;
        %data<owned> = $owned if defined $owned;
        %data<pulls> = $pulls if defined $pulls;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/issues","GET", :%data)
    }

    method list-for-authenticated-user(WebService::GitHub::Issues::ListForAuthenticatedUserFilter :$filter, WebService::GitHub::Issues::ListForAuthenticatedUserState :$state, Str :$labels, WebService::GitHub::Issues::ListForAuthenticatedUserSort :$sort, WebService::GitHub::Issues::ListForAuthenticatedUserDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<filter> = $filter if defined $filter;
        %data<state> = $state if defined $state;
        %data<labels> = $labels if defined $labels;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/user/issues","GET", :%data)
    }

    method list-for-org(Str $org, WebService::GitHub::Issues::ListForOrgFilter :$filter, WebService::GitHub::Issues::ListForOrgState :$state, Str :$labels, WebService::GitHub::Issues::ListForOrgSort :$sort, WebService::GitHub::Issues::ListForOrgDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<filter> = $filter if defined $filter;
        %data<state> = $state if defined $state;
        %data<labels> = $labels if defined $labels;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/issues","GET", :%data)
    }

    method list-for-repo(Str $owner, Str $repo, Str :$milestone, WebService::GitHub::Issues::ListForRepoState :$state, Str :$assignee, Str :$creator, Str :$mentioned, Str :$labels, WebService::GitHub::Issues::ListForRepoSort :$sort, WebService::GitHub::Issues::ListForRepoDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<milestone> = $milestone if defined $milestone;
        %data<state> = $state if defined $state;
        %data<assignee> = $assignee if defined $assignee;
        %data<creator> = $creator if defined $creator;
        %data<mentioned> = $mentioned if defined $mentioned;
        %data<labels> = $labels if defined $labels;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/issues","GET", :%data)
    }

    method lock(Str $owner, Str $repo, Int(Str) $issue-number, WebService::GitHub::Issues::LockLockReason :$lock-reason) {
        my %data;
        %data<lock_reason> = $lock-reason if defined $lock-reason;
        self.request("/repos/$owner/$repo/issues/$issue-number/lock","PUT", :%data)
    }

    method unlock(Str $owner, Str $repo, Int(Str) $issue-number) {
        self.request("/repos/$owner/$repo/issues/$issue-number/lock","DELETE")
    }

    method update(Str $owner, Str $repo, Int(Str) $issue-number, Positional :$labels, WebService::GitHub::Issues::UpdateState :$state, :$milestone, Str :$body, :$title, Positional :$assignees, Str :$assignee) {
        my %data;
        %data<labels> = $labels if defined $labels;
        %data<state> = $state if defined $state;
        %data<milestone> = $milestone if defined $milestone;
        %data<body> = $body if defined $body;
        %data<title> = $title if defined $title;
        %data<assignees> = $assignees if defined $assignees;
        %data<assignee> = $assignee if defined $assignee;
        self.request("/repos/$owner/$repo/issues/$issue-number","PATCH", :%data)
    }

}

