

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Issues::Comments::ListCommentsForRepoDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Issues::Comments::ListCommentsForRepoDirection must be either "asc" or "desc"';

subset WebService::GitHub::Issues::Comments::ListCommentsForRepoSort of Str where subset-is * eq 'created'|'updated', 'WebService::GitHub::Issues::Comments::ListCommentsForRepoSort must be either "created" or "updated"';


class WebService::GitHub::Issues::Comments  {
    also does WebService::GitHub::Role;
    method create-comment(Str $owner, Str $repo, Int(Str) $issue-number, Str :$body!) {
        my %data;
        %data<body> = $body;
        self.request("/repos/$owner/$repo/issues/$issue-number/comments","POST", :%data)
    }

    method delete-comment(Str $owner, Str $repo, Int(Str) $comment-id) {
        self.request("/repos/$owner/$repo/issues/comments/$comment-id","DELETE")
    }

    method get-comment(Str $owner, Str $repo, Int(Str) $comment-id) {
        self.request("/repos/$owner/$repo/issues/comments/$comment-id","GET")
    }

    method list-comments(Str $owner, Str $repo, Int(Str) $issue-number, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/issues/$issue-number/comments","GET", :%data)
    }

    method list-comments-for-repo(Str $owner, Str $repo, WebService::GitHub::Issues::Comments::ListCommentsForRepoSort :$sort, WebService::GitHub::Issues::Comments::ListCommentsForRepoDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/issues/comments","GET", :%data)
    }

    method update-comment(Str $owner, Str $repo, Int(Str) $comment-id, Str :$body!) {
        my %data;
        %data<body> = $body;
        self.request("/repos/$owner/$repo/issues/comments/$comment-id","PATCH", :%data)
    }

}

