

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Migrations::SourceImports::SetLfsPreferenceUseLfs of Str where subset-is * eq 'opt_in'|'opt_out', 'WebService::GitHub::Migrations::SourceImports::SetLfsPreferenceUseLfs must be either "opt_in" or "opt_out"';

subset WebService::GitHub::Migrations::SourceImports::StartImportVcs of Str where subset-is * eq 'subversion'|'git'|'mercurial'|'tfvc', 'WebService::GitHub::Migrations::SourceImports::StartImportVcs must be either "subversion", "git", "mercurial" or "tfvc"';


class WebService::GitHub::Migrations::SourceImports  {
    also does WebService::GitHub::Role;
    method cancel-import(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/import","DELETE")
    }

    method get-commit-authors(Str $owner, Str $repo, Int(Str) :$since) {
        my %data;
        %data<since> = $since if defined $since;
        self.request("/repos/$owner/$repo/import/authors","GET", :%data)
    }

    method get-import-status(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/import","GET")
    }

    method get-large-files(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/import/large_files","GET")
    }

    method map-commit-author(Str $owner, Str $repo, Int(Str) $author-id, Str :$remote-id, Str :$email, Str :$name) {
        my %data;
        %data<remote_id> = $remote-id if defined $remote-id;
        %data<email> = $email if defined $email;
        %data<name> = $name if defined $name;
        self.request("/repos/$owner/$repo/import/authors/$author-id","PATCH", :%data)
    }

    method set-lfs-preference(Str $owner, Str $repo, WebService::GitHub::Migrations::SourceImports::SetLfsPreferenceUseLfs :$use-lfs!) {
        my %data;
        %data<use_lfs> = $use-lfs;
        self.request("/repos/$owner/$repo/import/lfs","PATCH", :%data)
    }

    method start-import(Str $owner, Str $repo, Str :$vcs-url!, Str :$vcs-password, WebService::GitHub::Migrations::SourceImports::StartImportVcs :$vcs, Str :$tfvc-project, Str :$vcs-username) {
        my %data;
        %data<vcs_url> = $vcs-url;
        %data<vcs_password> = $vcs-password if defined $vcs-password;
        %data<vcs> = $vcs if defined $vcs;
        %data<tfvc_project> = $tfvc-project if defined $tfvc-project;
        %data<vcs_username> = $vcs-username if defined $vcs-username;
        self.request("/repos/$owner/$repo/import","PUT", :%data)
    }

    method update-import(Str $owner, Str $repo, Str :$vcs-username, Str :$vcs, Str :$tfvc-project, Str :$vcs-password) {
        my %data;
        %data<vcs_username> = $vcs-username if defined $vcs-username;
        %data<vcs> = $vcs if defined $vcs;
        %data<tfvc_project> = $tfvc-project if defined $tfvc-project;
        %data<vcs_password> = $vcs-password if defined $vcs-password;
        self.request("/repos/$owner/$repo/import","PATCH", :%data)
    }

}

