


use WebService::GitHub::Role;

class WebService::GitHub::OauthAuthorizations  {
    also does WebService::GitHub::Role;
    method create-authorization(Str :$note, Str :$client-id, Str :$fingerprint, Positional :$scopes, Str :$client-secret, Str :$note-url) {
        my %data;
        %data<note> = $note if defined $note;
        %data<client_id> = $client-id if defined $client-id;
        %data<fingerprint> = $fingerprint if defined $fingerprint;
        %data<scopes> = $scopes if defined $scopes;
        %data<client_secret> = $client-secret if defined $client-secret;
        %data<note_url> = $note-url if defined $note-url;
        self.request("/authorizations","POST", :%data)
    }

    method delete-authorization(Int(Str) $authorization-id) {
        self.request("/authorizations/$authorization-id","DELETE")
    }

    method delete-grant(Int(Str) $grant-id) {
        self.request("/applications/grants/$grant-id","DELETE")
    }

    method get-authorization(Int(Str) $authorization-id) {
        self.request("/authorizations/$authorization-id","GET")
    }

    method get-grant(Int(Str) $grant-id) {
        self.request("/applications/grants/$grant-id","GET")
    }

    method get-or-create-authorization-for-app(Str $client-id, Str :$client-secret!, Positional :$scopes, Str :$note-url, Str :$fingerprint, Str :$note) {
        my %data;
        %data<scopes> = $scopes if defined $scopes;
        %data<note_url> = $note-url if defined $note-url;
        %data<fingerprint> = $fingerprint if defined $fingerprint;
        %data<note> = $note if defined $note;
        %data<client_secret> = $client-secret;
        self.request("/authorizations/clients/$client-id","PUT", :%data)
    }

    method get-or-create-authorization-for-app-and-fingerprint(Str $client-id, Str $fingerprint, Str :$client-secret!, Str :$note-url, Positional :$scopes, Str :$note) {
        my %data;
        %data<note_url> = $note-url if defined $note-url;
        %data<client_secret> = $client-secret;
        %data<scopes> = $scopes if defined $scopes;
        %data<note> = $note if defined $note;
        self.request("/authorizations/clients/$client-id/$fingerprint","PUT", :%data)
    }

    method list-authorizations(Int(Str) :$per-page, Int(Str) :$page, Str :$client-id) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        %data<client_id> = $client-id if defined $client-id;
        self.request("/authorizations","GET", :%data)
    }

    method list-grants(Int(Str) :$per-page, Int(Str) :$page, Str :$client-id) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        %data<client_id> = $client-id if defined $client-id;
        self.request("/applications/grants","GET", :%data)
    }

    method update-authorization(Int(Str) $authorization-id, Positional :$scopes, Str :$fingerprint, Positional :$remove-scopes, Str :$note, Positional :$add-scopes, Str :$note-url) {
        my %data;
        %data<scopes> = $scopes if defined $scopes;
        %data<fingerprint> = $fingerprint if defined $fingerprint;
        %data<remove_scopes> = $remove-scopes if defined $remove-scopes;
        %data<note> = $note if defined $note;
        %data<add_scopes> = $add-scopes if defined $add-scopes;
        %data<note_url> = $note-url if defined $note-url;
        self.request("/authorizations/$authorization-id","PATCH", :%data)
    }

}

