

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Orgs::GetAuditLogInclude of Str where subset-is * eq 'web'|'git'|'all', 'WebService::GitHub::Orgs::GetAuditLogInclude must be either "web", "git" or "all"';

subset WebService::GitHub::Orgs::GetAuditLogOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Orgs::GetAuditLogOrder must be either "desc" or "asc"';

subset WebService::GitHub::Orgs::UpdateDefaultRepositoryPermission of Str where subset-is * eq 'read'|'write'|'admin'|'none', 'WebService::GitHub::Orgs::UpdateDefaultRepositoryPermission must be either "read", "write", "admin" or "none"';

subset WebService::GitHub::Orgs::UpdateMembersAllowedRepositoryCreationType of Str where subset-is * eq 'all'|'private'|'none', 'WebService::GitHub::Orgs::UpdateMembersAllowedRepositoryCreationType must be either "all", "private" or "none"';


class WebService::GitHub::Orgs  {
    also does WebService::GitHub::Role;
    method get(Str $org) {
        self.request("/orgs/$org","GET")
    }

    method get-audit-log(Str $org, Str :$phrase, WebService::GitHub::Orgs::GetAuditLogInclude :$include, Str :$after, Str :$before, WebService::GitHub::Orgs::GetAuditLogOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<phrase> = $phrase if defined $phrase;
        %data<include> = $include if defined $include;
        %data<after> = $after if defined $after;
        %data<before> = $before if defined $before;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/audit-log","GET", :%data)
    }

    method list(Int(Str) :$since, Int(Str) :$per-page) {
        my %data;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        self.request("/organizations","GET", :%data)
    }

    method list-app-installations(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/installations","GET", :%data)
    }

    method list-for-authenticated-user(Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/user/orgs","GET", :%data)
    }

    method list-for-user(Str $username, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/users/$username/orgs","GET", :%data)
    }

    method list-saml-sso-authorizations(Str $org) {
        self.request("/orgs/$org/credential-authorizations","GET")
    }

    method remove-saml-sso-authorization(Str $org, Int(Str) $credential-id) {
        self.request("/orgs/$org/credential-authorizations/$credential-id","DELETE")
    }

    method update(Str $org, Str :$twitter-username, Bool :$members-can-create-pages, Bool :$members-can-create-private-pages, WebService::GitHub::Orgs::UpdateMembersAllowedRepositoryCreationType :$members-allowed-repository-creation-type, WebService::GitHub::Orgs::UpdateDefaultRepositoryPermission :$default-repository-permission, Str :$billing-email, Bool :$members-can-create-internal-repositories, Str :$company, Bool :$has-organization-projects, Bool :$members-can-create-public-repositories, Str :$name, Str :$blog, Bool :$members-can-create-private-repositories, Bool :$members-can-create-public-pages, Str :$email, Str :$location, Bool :$members-can-create-repositories, Bool :$has-repository-projects, Str :$description) {
        my %data;
        %data<twitter_username> = $twitter-username if defined $twitter-username;
        %data<members_can_create_pages> = $members-can-create-pages if defined $members-can-create-pages;
        %data<members_can_create_private_pages> = $members-can-create-private-pages if defined $members-can-create-private-pages;
        %data<members_allowed_repository_creation_type> = $members-allowed-repository-creation-type if defined $members-allowed-repository-creation-type;
        %data<default_repository_permission> = $default-repository-permission if defined $default-repository-permission;
        %data<billing_email> = $billing-email if defined $billing-email;
        %data<members_can_create_internal_repositories> = $members-can-create-internal-repositories if defined $members-can-create-internal-repositories;
        %data<company> = $company if defined $company;
        %data<has_organization_projects> = $has-organization-projects if defined $has-organization-projects;
        %data<members_can_create_public_repositories> = $members-can-create-public-repositories if defined $members-can-create-public-repositories;
        %data<name> = $name if defined $name;
        %data<blog> = $blog if defined $blog;
        %data<members_can_create_private_repositories> = $members-can-create-private-repositories if defined $members-can-create-private-repositories;
        %data<members_can_create_public_pages> = $members-can-create-public-pages if defined $members-can-create-public-pages;
        %data<email> = $email if defined $email;
        %data<location> = $location if defined $location;
        %data<members_can_create_repositories> = $members-can-create-repositories if defined $members-can-create-repositories;
        %data<has_repository_projects> = $has-repository-projects if defined $has-repository-projects;
        %data<description> = $description if defined $description;
        self.request("/orgs/$org","PATCH", :%data)
    }

}

