

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Orgs::Members::CreateInvitationRole of Str where subset-is * eq 'admin'|'direct_member'|'billing_manager', 'WebService::GitHub::Orgs::Members::CreateInvitationRole must be either "admin", "direct_member" or "billing_manager"';

subset WebService::GitHub::Orgs::Members::ListMembersFilter of Str where subset-is * eq '2fa_disabled'|'all', 'WebService::GitHub::Orgs::Members::ListMembersFilter must be either "2fa_disabled" or "all"';

subset WebService::GitHub::Orgs::Members::ListMembersRole of Str where subset-is * eq 'all'|'admin'|'member', 'WebService::GitHub::Orgs::Members::ListMembersRole must be either "all", "admin" or "member"';

subset WebService::GitHub::Orgs::Members::ListMembershipsForAuthenticatedUserState of Str where subset-is * eq 'active'|'pending', 'WebService::GitHub::Orgs::Members::ListMembershipsForAuthenticatedUserState must be either "active" or "pending"';

subset WebService::GitHub::Orgs::Members::SetMembershipForUserRole of Str where subset-is * eq 'admin'|'member', 'WebService::GitHub::Orgs::Members::SetMembershipForUserRole must be either "admin" or "member"';

subset WebService::GitHub::Orgs::Members::UpdateMembershipForAuthenticatedUserState of Str where subset-is * eq 'active', 'WebService::GitHub::Orgs::Members::UpdateMembershipForAuthenticatedUserState must be either "active"';


class WebService::GitHub::Orgs::Members  {
    also does WebService::GitHub::Role;
    method cancel-invitation(Str $org, Int(Str) $invitation-id) {
        self.request("/orgs/$org/invitations/$invitation-id","DELETE")
    }

    method check-membership-for-user(Str $org, Str $username) {
        self.request("/orgs/$org/members/$username","GET")
    }

    method check-public-membership-for-user(Str $org, Str $username) {
        self.request("/orgs/$org/public_members/$username","GET")
    }

    method create-invitation(Str $org, Int(Str) :$invitee-id, WebService::GitHub::Orgs::Members::CreateInvitationRole :$role, Positional :$team-ids, Str :$email) {
        my %data;
        %data<invitee_id> = $invitee-id if defined $invitee-id;
        %data<role> = $role if defined $role;
        %data<team_ids> = $team-ids if defined $team-ids;
        %data<email> = $email if defined $email;
        self.request("/orgs/$org/invitations","POST", :%data)
    }

    method get-membership-for-authenticated-user(Str $org) {
        self.request("/user/memberships/orgs/$org","GET")
    }

    method get-membership-for-user(Str $org, Str $username) {
        self.request("/orgs/$org/memberships/$username","GET")
    }

    method list-failed-invitations(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/failed_invitations","GET", :%data)
    }

    method list-invitation-teams(Str $org, Int(Str) $invitation-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/invitations/$invitation-id/teams","GET", :%data)
    }

    method list-members(Str $org, WebService::GitHub::Orgs::Members::ListMembersFilter :$filter, WebService::GitHub::Orgs::Members::ListMembersRole :$role, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<filter> = $filter if defined $filter;
        %data<role> = $role if defined $role;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/members","GET", :%data)
    }

    method list-memberships-for-authenticated-user(WebService::GitHub::Orgs::Members::ListMembershipsForAuthenticatedUserState :$state, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<state> = $state if defined $state;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/user/memberships/orgs","GET", :%data)
    }

    method list-pending-invitations(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/invitations","GET", :%data)
    }

    method list-public-members(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/public_members","GET", :%data)
    }

    method remove-member(Str $org, Str $username) {
        self.request("/orgs/$org/members/$username","DELETE")
    }

    method remove-membership-for-user(Str $org, Str $username) {
        self.request("/orgs/$org/memberships/$username","DELETE")
    }

    method remove-public-membership-for-authenticated-user(Str $org, Str $username) {
        self.request("/orgs/$org/public_members/$username","DELETE")
    }

    method set-membership-for-user(Str $org, Str $username, WebService::GitHub::Orgs::Members::SetMembershipForUserRole :$role) {
        my %data;
        %data<role> = $role if defined $role;
        self.request("/orgs/$org/memberships/$username","PUT", :%data)
    }

    method set-public-membership-for-authenticated-user(Str $org, Str $username) {
        self.request("/orgs/$org/public_members/$username","PUT")
    }

    method update-membership-for-authenticated-user(Str $org, WebService::GitHub::Orgs::Members::UpdateMembershipForAuthenticatedUserState :$state!) {
        my %data;
        %data<state> = $state;
        self.request("/user/memberships/orgs/$org","PATCH", :%data)
    }

}

