

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Projects::ListForOrgState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Projects::ListForOrgState must be either "open", "closed" or "all"';

subset WebService::GitHub::Projects::ListForRepoState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Projects::ListForRepoState must be either "open", "closed" or "all"';

subset WebService::GitHub::Projects::ListForUserState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Projects::ListForUserState must be either "open", "closed" or "all"';

subset WebService::GitHub::Projects::UpdateOrganizationPermission of Str where subset-is * eq 'read'|'write'|'admin'|'none', 'WebService::GitHub::Projects::UpdateOrganizationPermission must be either "read", "write", "admin" or "none"';


class WebService::GitHub::Projects  {
    also does WebService::GitHub::Role;
    method create-for-authenticated-user(Str :$name!, Str :$body) {
        my %data;
        %data<body> = $body if defined $body;
        %data<name> = $name;
        self.request("/user/projects","POST", :%data)
    }

    method create-for-org(Str $org, Str :$name!, Str :$body) {
        my %data;
        %data<body> = $body if defined $body;
        %data<name> = $name;
        self.request("/orgs/$org/projects","POST", :%data)
    }

    method create-for-repo(Str $owner, Str $repo, Str :$name!, Str :$body) {
        my %data;
        %data<body> = $body if defined $body;
        %data<name> = $name;
        self.request("/repos/$owner/$repo/projects","POST", :%data)
    }

    method delete(Int(Str) $project-id) {
        self.request("/projects/$project-id","DELETE")
    }

    method get(Int(Str) $project-id) {
        self.request("/projects/$project-id","GET")
    }

    method list-for-org(Str $org, WebService::GitHub::Projects::ListForOrgState :$state, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<state> = $state if defined $state;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/projects","GET", :%data)
    }

    method list-for-repo(Str $owner, Str $repo, WebService::GitHub::Projects::ListForRepoState :$state, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<state> = $state if defined $state;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/projects","GET", :%data)
    }

    method list-for-user(Str $username, WebService::GitHub::Projects::ListForUserState :$state, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<state> = $state if defined $state;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/users/$username/projects","GET", :%data)
    }

    method update(Int(Str) $project-id, WebService::GitHub::Projects::UpdateOrganizationPermission :$organization-permission, Str :$body, Str :$name, Str :$state, Bool :$private) {
        my %data;
        %data<organization_permission> = $organization-permission if defined $organization-permission;
        %data<body> = $body if defined $body;
        %data<name> = $name if defined $name;
        %data<state> = $state if defined $state;
        %data<private> = $private if defined $private;
        self.request("/projects/$project-id","PATCH", :%data)
    }

}

