

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Pulls::ListDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Pulls::ListDirection must be either "asc" or "desc"';

subset WebService::GitHub::Pulls::ListSort of Str where subset-is * eq 'created'|'updated'|'popularity'|'long-running', 'WebService::GitHub::Pulls::ListSort must be either "created", "updated", "popularity" or "long-running"';

subset WebService::GitHub::Pulls::ListState of Str where subset-is * eq 'open'|'closed'|'all', 'WebService::GitHub::Pulls::ListState must be either "open", "closed" or "all"';

subset WebService::GitHub::Pulls::MergeMergeMethod of Str where subset-is * eq 'merge'|'squash'|'rebase', 'WebService::GitHub::Pulls::MergeMergeMethod must be either "merge", "squash" or "rebase"';

subset WebService::GitHub::Pulls::UpdateState of Str where subset-is * eq 'open'|'closed', 'WebService::GitHub::Pulls::UpdateState must be either "open" or "closed"';


class WebService::GitHub::Pulls  {
    also does WebService::GitHub::Role;
    method check-if-merged(Str $owner, Str $repo, Int(Str) $pull-number) {
        self.request("/repos/$owner/$repo/pulls/$pull-number/merge","GET")
    }

    method create(Str $owner, Str $repo, Str :$base!, Str :$head!, Bool :$maintainer-can-modify, Str :$title, Str :$body, Int(Str) :$issue, Bool :$draft) {
        my %data;
        %data<maintainer_can_modify> = $maintainer-can-modify if defined $maintainer-can-modify;
        %data<title> = $title if defined $title;
        %data<base> = $base;
        %data<head> = $head;
        %data<body> = $body if defined $body;
        %data<issue> = $issue if defined $issue;
        %data<draft> = $draft if defined $draft;
        self.request("/repos/$owner/$repo/pulls","POST", :%data)
    }

    method get(Str $owner, Str $repo, Int(Str) $pull-number) {
        self.request("/repos/$owner/$repo/pulls/$pull-number","GET")
    }

    method list(Str $owner, Str $repo, WebService::GitHub::Pulls::ListState :$state, Str :$head, Str :$base, WebService::GitHub::Pulls::ListSort :$sort, WebService::GitHub::Pulls::ListDirection :$direction, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<state> = $state if defined $state;
        %data<head> = $head if defined $head;
        %data<base> = $base if defined $base;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls","GET", :%data)
    }

    method list-commits(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/$pull-number/commits","GET", :%data)
    }

    method list-files(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/$pull-number/files","GET", :%data)
    }

    method merge(Str $owner, Str $repo, Int(Str) $pull-number, Str :$sha, WebService::GitHub::Pulls::MergeMergeMethod :$merge-method, Str :$commit-message, Str :$commit-title) {
        my %data;
        %data<sha> = $sha if defined $sha;
        %data<merge_method> = $merge-method if defined $merge-method;
        %data<commit_message> = $commit-message if defined $commit-message;
        %data<commit_title> = $commit-title if defined $commit-title;
        self.request("/repos/$owner/$repo/pulls/$pull-number/merge","PUT", :%data)
    }

    method update(Str $owner, Str $repo, Int(Str) $pull-number, Str :$body, WebService::GitHub::Pulls::UpdateState :$state, Bool :$maintainer-can-modify, Str :$base, Str :$title) {
        my %data;
        %data<body> = $body if defined $body;
        %data<state> = $state if defined $state;
        %data<maintainer_can_modify> = $maintainer-can-modify if defined $maintainer-can-modify;
        %data<base> = $base if defined $base;
        %data<title> = $title if defined $title;
        self.request("/repos/$owner/$repo/pulls/$pull-number","PATCH", :%data)
    }

    method update-branch(Str $owner, Str $repo, Int(Str) $pull-number, Str :$expected-head-sha) {
        my %data;
        %data<expected_head_sha> = $expected-head-sha if defined $expected-head-sha;
        self.request("/repos/$owner/$repo/pulls/$pull-number/update-branch","PUT", :%data)
    }

}

