

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Pulls::Comments::CreateReviewCommentSide of Str where subset-is * eq 'LEFT'|'RIGHT', 'WebService::GitHub::Pulls::Comments::CreateReviewCommentSide must be either "LEFT" or "RIGHT"';

subset WebService::GitHub::Pulls::Comments::CreateReviewCommentStartSide of Str where subset-is * eq 'LEFT'|'RIGHT'|'side', 'WebService::GitHub::Pulls::Comments::CreateReviewCommentStartSide must be either "LEFT", "RIGHT" or "side"';

subset WebService::GitHub::Pulls::Comments::ListReviewCommentsDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Pulls::Comments::ListReviewCommentsDirection must be either "asc" or "desc"';

subset WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoDirection must be either "asc" or "desc"';

subset WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoSort of Str where subset-is * eq 'created'|'updated'|'created_at', 'WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoSort must be either "created", "updated" or "created_at"';

subset WebService::GitHub::Pulls::Comments::ListReviewCommentsSort of Str where subset-is * eq 'created'|'updated', 'WebService::GitHub::Pulls::Comments::ListReviewCommentsSort must be either "created" or "updated"';


class WebService::GitHub::Pulls::Comments  {
    also does WebService::GitHub::Role;
    method create-reply-for-review-comment(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $comment-id, Str :$body!) {
        my %data;
        %data<body> = $body;
        self.request("/repos/$owner/$repo/pulls/$pull-number/comments/$comment-id/replies","POST", :%data)
    }

    method create-review-comment(Str $owner, Str $repo, Int(Str) $pull-number, Str :$body!, WebService::GitHub::Pulls::Comments::CreateReviewCommentSide :$side, Int(Str) :$start-line, Int(Str) :$line, Str :$path, Str :$commit-id, WebService::GitHub::Pulls::Comments::CreateReviewCommentStartSide :$start-side, Int(Str) :$in-reply-to, Int(Str) :$position) {
        my %data;
        %data<side> = $side if defined $side;
        %data<body> = $body;
        %data<start_line> = $start-line if defined $start-line;
        %data<line> = $line if defined $line;
        %data<path> = $path if defined $path;
        %data<commit_id> = $commit-id if defined $commit-id;
        %data<start_side> = $start-side if defined $start-side;
        %data<in_reply_to> = $in-reply-to if defined $in-reply-to;
        %data<position> = $position if defined $position;
        self.request("/repos/$owner/$repo/pulls/$pull-number/comments","POST", :%data)
    }

    method delete-review-comment(Str $owner, Str $repo, Int(Str) $comment-id) {
        self.request("/repos/$owner/$repo/pulls/comments/$comment-id","DELETE")
    }

    method get-review-comment(Str $owner, Str $repo, Int(Str) $comment-id) {
        self.request("/repos/$owner/$repo/pulls/comments/$comment-id","GET")
    }

    method list-review-comments(Str $owner, Str $repo, Int(Str) $pull-number, WebService::GitHub::Pulls::Comments::ListReviewCommentsSort :$sort, WebService::GitHub::Pulls::Comments::ListReviewCommentsDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/$pull-number/comments","GET", :%data)
    }

    method list-review-comments-for-repo(Str $owner, Str $repo, WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoSort :$sort, WebService::GitHub::Pulls::Comments::ListReviewCommentsForRepoDirection :$direction, Str :$since, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<since> = $since if defined $since;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/comments","GET", :%data)
    }

    method update-review-comment(Str $owner, Str $repo, Int(Str) $comment-id, Str :$body!) {
        my %data;
        %data<body> = $body;
        self.request("/repos/$owner/$repo/pulls/comments/$comment-id","PATCH", :%data)
    }

}

