

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Pulls::Reviews::CreateReviewEvent of Str where subset-is * eq 'APPROVE'|'REQUEST_CHANGES'|'COMMENT', 'WebService::GitHub::Pulls::Reviews::CreateReviewEvent must be either "APPROVE", "REQUEST_CHANGES" or "COMMENT"';

subset WebService::GitHub::Pulls::Reviews::SubmitReviewEvent of Str where subset-is * eq 'APPROVE'|'REQUEST_CHANGES'|'COMMENT', 'WebService::GitHub::Pulls::Reviews::SubmitReviewEvent must be either "APPROVE", "REQUEST_CHANGES" or "COMMENT"';


class WebService::GitHub::Pulls::Reviews  {
    also does WebService::GitHub::Role;
    method create-review(Str $owner, Str $repo, Int(Str) $pull-number, Str :$commit-id, Positional :$comments, Str :$body, WebService::GitHub::Pulls::Reviews::CreateReviewEvent :$event) {
        my %data;
        %data<commit_id> = $commit-id if defined $commit-id;
        %data<comments> = $comments if defined $comments;
        %data<body> = $body if defined $body;
        %data<event> = $event if defined $event;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews","POST", :%data)
    }

    method delete-pending-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id) {
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id","DELETE")
    }

    method dismiss-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id, Str :$message!, Str :$event) {
        my %data;
        %data<message> = $message;
        %data<event> = $event if defined $event;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id/dismissals","PUT", :%data)
    }

    method get-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id) {
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id","GET")
    }

    method list-comments-for-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id/comments","GET", :%data)
    }

    method list-reviews(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews","GET", :%data)
    }

    method submit-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id, WebService::GitHub::Pulls::Reviews::SubmitReviewEvent :$event!, Str :$body) {
        my %data;
        %data<event> = $event;
        %data<body> = $body if defined $body;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id/events","POST", :%data)
    }

    method update-review(Str $owner, Str $repo, Int(Str) $pull-number, Int(Str) $review-id, Str :$body!) {
        my %data;
        %data<body> = $body;
        self.request("/repos/$owner/$repo/pulls/$pull-number/reviews/$review-id","PUT", :%data)
    }

}

