

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Repos::CreateInOrgVisibility of Str where subset-is * eq 'public'|'private'|'visibility'|'internal', 'WebService::GitHub::Repos::CreateInOrgVisibility must be either "public", "private", "visibility" or "internal"';

subset WebService::GitHub::Repos::ListForAuthenticatedUserDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Repos::ListForAuthenticatedUserDirection must be either "asc" or "desc"';

subset WebService::GitHub::Repos::ListForAuthenticatedUserSort of Str where subset-is * eq 'created'|'updated'|'pushed'|'full_name', 'WebService::GitHub::Repos::ListForAuthenticatedUserSort must be either "created", "updated", "pushed" or "full_name"';

subset WebService::GitHub::Repos::ListForAuthenticatedUserType of Str where subset-is * eq 'all'|'owner'|'public'|'private'|'member', 'WebService::GitHub::Repos::ListForAuthenticatedUserType must be either "all", "owner", "public", "private" or "member"';

subset WebService::GitHub::Repos::ListForAuthenticatedUserVisibility of Str where subset-is * eq 'all'|'public'|'private', 'WebService::GitHub::Repos::ListForAuthenticatedUserVisibility must be either "all", "public" or "private"';

subset WebService::GitHub::Repos::ListForOrgDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Repos::ListForOrgDirection must be either "asc" or "desc"';

subset WebService::GitHub::Repos::ListForOrgSort of Str where subset-is * eq 'created'|'updated'|'pushed'|'full_name', 'WebService::GitHub::Repos::ListForOrgSort must be either "created", "updated", "pushed" or "full_name"';

subset WebService::GitHub::Repos::ListForOrgType of Str where subset-is * eq 'all'|'public'|'private'|'forks'|'sources'|'member'|'internal', 'WebService::GitHub::Repos::ListForOrgType must be either "all", "public", "private", "forks", "sources", "member" or "internal"';

subset WebService::GitHub::Repos::ListForUserDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Repos::ListForUserDirection must be either "asc" or "desc"';

subset WebService::GitHub::Repos::ListForUserSort of Str where subset-is * eq 'created'|'updated'|'pushed'|'full_name', 'WebService::GitHub::Repos::ListForUserSort must be either "created", "updated", "pushed" or "full_name"';

subset WebService::GitHub::Repos::ListForUserType of Str where subset-is * eq 'all'|'owner'|'member', 'WebService::GitHub::Repos::ListForUserType must be either "all", "owner" or "member"';

subset WebService::GitHub::Repos::UpdateVisibility of Str where subset-is * eq 'public'|'private'|'visibility'|'internal', 'WebService::GitHub::Repos::UpdateVisibility must be either "public", "private", "visibility" or "internal"';


class WebService::GitHub::Repos  {
    also does WebService::GitHub::Role;
    method check-vulnerability-alerts(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/vulnerability-alerts","GET")
    }

    method create-dispatch-event(Str $owner, Str $repo, Str :$event-type!, Associative :$client-payload) {
        my %data;
        %data<client_payload> = $client-payload if defined $client-payload;
        %data<event_type> = $event-type;
        self.request("/repos/$owner/$repo/dispatches","POST", :%data)
    }

    method create-for-authenticated-user(Str :$name!, Str :$description, Bool :$has-projects, Bool :$private, Bool :$delete-branch-on-merge, Bool :$has-wiki, Str :$license-template, Str :$gitignore-template, Bool :$has-downloads, Bool :$auto-init, Bool :$allow-merge-commit, Bool :$has-issues, Bool :$allow-rebase-merge, Bool :$allow-squash-merge, Str :$homepage, Int(Str) :$team-id, Bool :$is-template) {
        my %data;
        %data<description> = $description if defined $description;
        %data<has_projects> = $has-projects if defined $has-projects;
        %data<private> = $private if defined $private;
        %data<delete_branch_on_merge> = $delete-branch-on-merge if defined $delete-branch-on-merge;
        %data<has_wiki> = $has-wiki if defined $has-wiki;
        %data<license_template> = $license-template if defined $license-template;
        %data<gitignore_template> = $gitignore-template if defined $gitignore-template;
        %data<has_downloads> = $has-downloads if defined $has-downloads;
        %data<auto_init> = $auto-init if defined $auto-init;
        %data<allow_merge_commit> = $allow-merge-commit if defined $allow-merge-commit;
        %data<name> = $name;
        %data<has_issues> = $has-issues if defined $has-issues;
        %data<allow_rebase_merge> = $allow-rebase-merge if defined $allow-rebase-merge;
        %data<allow_squash_merge> = $allow-squash-merge if defined $allow-squash-merge;
        %data<homepage> = $homepage if defined $homepage;
        %data<team_id> = $team-id if defined $team-id;
        %data<is_template> = $is-template if defined $is-template;
        self.request("/user/repos","POST", :%data)
    }

    method create-in-org(Str $org, Str :$name!, Bool :$private, Int(Str) :$team-id, Bool :$has-projects, Bool :$allow-rebase-merge, Bool :$is-template, Str :$description, Bool :$has-wiki, Str :$license-template, Bool :$has-issues, Str :$gitignore-template, Bool :$auto-init, WebService::GitHub::Repos::CreateInOrgVisibility :$visibility, Str :$homepage, Bool :$allow-merge-commit, Bool :$allow-squash-merge, Bool :$delete-branch-on-merge) {
        my %data;
        %data<private> = $private if defined $private;
        %data<team_id> = $team-id if defined $team-id;
        %data<has_projects> = $has-projects if defined $has-projects;
        %data<allow_rebase_merge> = $allow-rebase-merge if defined $allow-rebase-merge;
        %data<is_template> = $is-template if defined $is-template;
        %data<description> = $description if defined $description;
        %data<has_wiki> = $has-wiki if defined $has-wiki;
        %data<name> = $name;
        %data<license_template> = $license-template if defined $license-template;
        %data<has_issues> = $has-issues if defined $has-issues;
        %data<gitignore_template> = $gitignore-template if defined $gitignore-template;
        %data<auto_init> = $auto-init if defined $auto-init;
        %data<visibility> = $visibility if defined $visibility;
        %data<homepage> = $homepage if defined $homepage;
        %data<allow_merge_commit> = $allow-merge-commit if defined $allow-merge-commit;
        %data<allow_squash_merge> = $allow-squash-merge if defined $allow-squash-merge;
        %data<delete_branch_on_merge> = $delete-branch-on-merge if defined $delete-branch-on-merge;
        self.request("/orgs/$org/repos","POST", :%data)
    }

    method create-using-template(Str $template-owner, Str $template-repo, Str :$name!, Bool :$include-all-branches, Str :$owner, Bool :$private, Str :$description) {
        my %data;
        %data<name> = $name;
        %data<include_all_branches> = $include-all-branches if defined $include-all-branches;
        %data<owner> = $owner if defined $owner;
        %data<private> = $private if defined $private;
        %data<description> = $description if defined $description;
        self.request("/repos/$template-owner/$template-repo/generate","POST", :%data)
    }

    method delete(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo","DELETE")
    }

    method disable-automated-security-fixes(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/automated-security-fixes","DELETE")
    }

    method disable-vulnerability-alerts(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/vulnerability-alerts","DELETE")
    }

    method enable-automated-security-fixes(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/automated-security-fixes","PUT")
    }

    method enable-vulnerability-alerts(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/vulnerability-alerts","PUT")
    }

    method get(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo","GET")
    }

    method get-all-topics(Str $owner, Str $repo, Int(Str) :$page, Int(Str) :$per-page) {
        my %data;
        %data<page> = $page if defined $page;
        %data<per_page> = $per-page if defined $per-page;
        self.request("/repos/$owner/$repo/topics","GET", :%data)
    }

    method list-contributors(Str $owner, Str $repo, Str :$anon, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<anon> = $anon if defined $anon;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/contributors","GET", :%data)
    }

    method list-for-authenticated-user(WebService::GitHub::Repos::ListForAuthenticatedUserVisibility :$visibility, Str :$affiliation, WebService::GitHub::Repos::ListForAuthenticatedUserType :$type, WebService::GitHub::Repos::ListForAuthenticatedUserSort :$sort, WebService::GitHub::Repos::ListForAuthenticatedUserDirection :$direction, Int(Str) :$per-page, Int(Str) :$page, Str :$since, Str :$before) {
        my %data;
        %data<visibility> = $visibility if defined $visibility;
        %data<affiliation> = $affiliation if defined $affiliation;
        %data<type> = $type if defined $type;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        %data<since> = $since if defined $since;
        %data<before> = $before if defined $before;
        self.request("/user/repos","GET", :%data)
    }

    method list-for-org(Str $org, WebService::GitHub::Repos::ListForOrgType :$type, WebService::GitHub::Repos::ListForOrgSort :$sort, WebService::GitHub::Repos::ListForOrgDirection :$direction, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<type> = $type if defined $type;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/repos","GET", :%data)
    }

    method list-for-user(Str $username, WebService::GitHub::Repos::ListForUserType :$type, WebService::GitHub::Repos::ListForUserSort :$sort, WebService::GitHub::Repos::ListForUserDirection :$direction, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<type> = $type if defined $type;
        %data<sort> = $sort if defined $sort;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/users/$username/repos","GET", :%data)
    }

    method list-languages(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/languages","GET")
    }

    method list-public(Int(Str) :$since) {
        my %data;
        %data<since> = $since if defined $since;
        self.request("/repositories","GET", :%data)
    }

    method list-tags(Str $owner, Str $repo, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/tags","GET", :%data)
    }

    method list-teams(Str $owner, Str $repo, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/teams","GET", :%data)
    }

    method replace-all-topics(Str $owner, Str $repo, Positional :$names!) {
        my %data;
        %data<names> = $names;
        self.request("/repos/$owner/$repo/topics","PUT", :%data)
    }

    method transfer(Str $owner, Str $repo, Str :$new-owner!, Positional :$team-ids) {
        my %data;
        %data<new_owner> = $new-owner;
        %data<team_ids> = $team-ids if defined $team-ids;
        self.request("/repos/$owner/$repo/transfer","POST", :%data)
    }

    method update(Str $owner, Str $repo, Str :$default-branch, Str :$description, Str :$name, Str :$homepage, Bool :$has-projects, Bool :$archived, WebService::GitHub::Repos::UpdateVisibility :$visibility, Bool :$delete-branch-on-merge, Bool :$allow-merge-commit, Bool :$is-template, Bool :$private, Bool :$has-wiki, Bool :$has-issues, Bool :$allow-squash-merge, Bool :$allow-rebase-merge) {
        my %data;
        %data<default_branch> = $default-branch if defined $default-branch;
        %data<description> = $description if defined $description;
        %data<name> = $name if defined $name;
        %data<homepage> = $homepage if defined $homepage;
        %data<has_projects> = $has-projects if defined $has-projects;
        %data<archived> = $archived if defined $archived;
        %data<visibility> = $visibility if defined $visibility;
        %data<delete_branch_on_merge> = $delete-branch-on-merge if defined $delete-branch-on-merge;
        %data<allow_merge_commit> = $allow-merge-commit if defined $allow-merge-commit;
        %data<is_template> = $is-template if defined $is-template;
        %data<private> = $private if defined $private;
        %data<has_wiki> = $has-wiki if defined $has-wiki;
        %data<has_issues> = $has-issues if defined $has-issues;
        %data<allow_squash_merge> = $allow-squash-merge if defined $allow-squash-merge;
        %data<allow_rebase_merge> = $allow-rebase-merge if defined $allow-rebase-merge;
        self.request("/repos/$owner/$repo","PATCH", :%data)
    }

}

