


use WebService::GitHub::Role;

class WebService::GitHub::Repos::Branches  {
    also does WebService::GitHub::Role;
    method add-app-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$apps!) {
        my %data;
        %data<apps> = $apps;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/apps","POST", :%data)
    }

    method add-status-check-contexts(Str $owner, Str $repo, Str $branch, Positional :$contexts!) {
        my %data;
        %data<contexts> = $contexts;
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks/contexts","POST", :%data)
    }

    method add-team-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$teams!) {
        my %data;
        %data<teams> = $teams;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/teams","POST", :%data)
    }

    method add-user-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$users!) {
        my %data;
        %data<users> = $users;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/users","POST", :%data)
    }

    method create-commit-signature-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_signatures","POST")
    }

    method delete-access-restrictions(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions","DELETE")
    }

    method delete-admin-branch-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/enforce_admins","DELETE")
    }

    method delete-branch-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection","DELETE")
    }

    method delete-commit-signature-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_signatures","DELETE")
    }

    method delete-pull-request-review-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_pull_request_reviews","DELETE")
    }

    method get-access-restrictions(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions","GET")
    }

    method get-admin-branch-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/enforce_admins","GET")
    }

    method get-all-status-check-contexts(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks/contexts","GET")
    }

    method get-apps-with-access-to-protected-branch(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/apps","GET")
    }

    method get-branch(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch","GET")
    }

    method get-branch-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection","GET")
    }

    method get-commit-signature-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_signatures","GET")
    }

    method get-pull-request-review-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_pull_request_reviews","GET")
    }

    method get-status-checks-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks","GET")
    }

    method get-teams-with-access-to-protected-branch(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/teams","GET")
    }

    method get-users-with-access-to-protected-branch(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/users","GET")
    }

    method list-branches(Str $owner, Str $repo, Bool :$protected, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<protected> = $protected if defined $protected;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/branches","GET", :%data)
    }

    method remove-app-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$apps!) {
        my %data;
        %data<apps> = $apps;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/apps","DELETE", :%data)
    }

    method remove-status-check-contexts(Str $owner, Str $repo, Str $branch, Positional :$contexts!) {
        my %data;
        %data<contexts> = $contexts;
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks/contexts","DELETE", :%data)
    }

    method remove-status-check-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks","DELETE")
    }

    method remove-team-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$teams!) {
        my %data;
        %data<teams> = $teams;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/teams","DELETE", :%data)
    }

    method remove-user-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$users!) {
        my %data;
        %data<users> = $users;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/users","DELETE", :%data)
    }

    method rename-branch(Str $owner, Str $repo, Str $branch, Str :$new-name!) {
        my %data;
        %data<new_name> = $new-name;
        self.request("/repos/$owner/$repo/branches/$branch/rename","POST", :%data)
    }

    method set-admin-branch-protection(Str $owner, Str $repo, Str $branch) {
        self.request("/repos/$owner/$repo/branches/$branch/protection/enforce_admins","POST")
    }

    method set-app-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$apps!) {
        my %data;
        %data<apps> = $apps;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/apps","PUT", :%data)
    }

    method set-status-check-contexts(Str $owner, Str $repo, Str $branch, Positional :$contexts!) {
        my %data;
        %data<contexts> = $contexts;
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks/contexts","PUT", :%data)
    }

    method set-team-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$teams!) {
        my %data;
        %data<teams> = $teams;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/teams","PUT", :%data)
    }

    method set-user-access-restrictions(Str $owner, Str $repo, Str $branch, Positional :$users!) {
        my %data;
        %data<users> = $users;
        self.request("/repos/$owner/$repo/branches/$branch/protection/restrictions/users","PUT", :%data)
    }

    method update-branch-protection(Str $owner, Str $repo, Str $branch, Bool :$enforce-admins!, Associative :$required-pull-request-reviews!, Associative :$restrictions!, Associative :$required-status-checks!, Bool :$allow-force-pushes, Bool :$required-linear-history, Bool :$allow-deletions) {
        my %data;
        %data<enforce_admins> = $enforce-admins;
        %data<allow_force_pushes> = $allow-force-pushes if defined $allow-force-pushes;
        %data<required_pull_request_reviews> = $required-pull-request-reviews;
        %data<required_linear_history> = $required-linear-history if defined $required-linear-history;
        %data<restrictions> = $restrictions;
        %data<required_status_checks> = $required-status-checks;
        %data<allow_deletions> = $allow-deletions if defined $allow-deletions;
        self.request("/repos/$owner/$repo/branches/$branch/protection","PUT", :%data)
    }

    method update-pull-request-review-protection(Str $owner, Str $repo, Str $branch, Associative :$dismissal-restrictions, Bool :$require-code-owner-reviews, Bool :$dismiss-stale-reviews, Int(Str) :$required-approving-review-count) {
        my %data;
        %data<dismissal_restrictions> = $dismissal-restrictions if defined $dismissal-restrictions;
        %data<require_code_owner_reviews> = $require-code-owner-reviews if defined $require-code-owner-reviews;
        %data<dismiss_stale_reviews> = $dismiss-stale-reviews if defined $dismiss-stale-reviews;
        %data<required_approving_review_count> = $required-approving-review-count if defined $required-approving-review-count;
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_pull_request_reviews","PATCH", :%data)
    }

    method update-status-check-protection(Str $owner, Str $repo, Str $branch, Bool :$strict, Positional :$contexts) {
        my %data;
        %data<strict> = $strict if defined $strict;
        %data<contexts> = $contexts if defined $contexts;
        self.request("/repos/$owner/$repo/branches/$branch/protection/required_status_checks","PATCH", :%data)
    }

}

