

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Repos::Deployments::CreateDeploymentStatusEnvironment of Str where subset-is * eq 'production'|'staging'|'qa', 'WebService::GitHub::Repos::Deployments::CreateDeploymentStatusEnvironment must be either "production", "staging" or "qa"';

subset WebService::GitHub::Repos::Deployments::CreateDeploymentStatusState of Str where subset-is * eq 'error'|'failure'|'inactive'|'in_progress'|'queued'|'pending'|'success', 'WebService::GitHub::Repos::Deployments::CreateDeploymentStatusState must be either "error", "failure", "inactive", "in_progress", "queued", "pending" or "success"';


class WebService::GitHub::Repos::Deployments  {
    also does WebService::GitHub::Role;
    method create-deployment(Str $owner, Str $repo, Str :$ref!, Str :$environment, Bool :$auto-merge, :$payload, Positional :$required-contexts, Bool :$production-environment, Str :$created-at, Str :$task, Str :$description, Bool :$transient-environment) {
        my %data;
        %data<environment> = $environment if defined $environment;
        %data<auto_merge> = $auto-merge if defined $auto-merge;
        %data<payload> = $payload if defined $payload;
        %data<required_contexts> = $required-contexts if defined $required-contexts;
        %data<production_environment> = $production-environment if defined $production-environment;
        %data<created_at> = $created-at if defined $created-at;
        %data<task> = $task if defined $task;
        %data<description> = $description if defined $description;
        %data<ref> = $ref;
        %data<transient_environment> = $transient-environment if defined $transient-environment;
        self.request("/repos/$owner/$repo/deployments","POST", :%data)
    }

    method create-deployment-status(Str $owner, Str $repo, Int(Str) $deployment-id, WebService::GitHub::Repos::Deployments::CreateDeploymentStatusState :$state!, Str :$target-url, WebService::GitHub::Repos::Deployments::CreateDeploymentStatusEnvironment :$environment, Str :$description, Bool :$auto-inactive, Str :$environment-url, Str :$log-url) {
        my %data;
        %data<target_url> = $target-url if defined $target-url;
        %data<state> = $state;
        %data<environment> = $environment if defined $environment;
        %data<description> = $description if defined $description;
        %data<auto_inactive> = $auto-inactive if defined $auto-inactive;
        %data<environment_url> = $environment-url if defined $environment-url;
        %data<log_url> = $log-url if defined $log-url;
        self.request("/repos/$owner/$repo/deployments/$deployment-id/statuses","POST", :%data)
    }

    method delete-deployment(Str $owner, Str $repo, Int(Str) $deployment-id) {
        self.request("/repos/$owner/$repo/deployments/$deployment-id","DELETE")
    }

    method get-deployment(Str $owner, Str $repo, Int(Str) $deployment-id) {
        self.request("/repos/$owner/$repo/deployments/$deployment-id","GET")
    }

    method get-deployment-status(Str $owner, Str $repo, Int(Str) $deployment-id, Int(Str) $status-id) {
        self.request("/repos/$owner/$repo/deployments/$deployment-id/statuses/$status-id","GET")
    }

    method list-deployment-statuses(Str $owner, Str $repo, Int(Str) $deployment-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/deployments/$deployment-id/statuses","GET", :%data)
    }

    method list-deployments(Str $owner, Str $repo, Str :$sha, Str :$ref, Str :$task, Str :$environment, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<sha> = $sha if defined $sha;
        %data<ref> = $ref if defined $ref;
        %data<task> = $task if defined $task;
        %data<environment> = $environment if defined $environment;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/deployments","GET", :%data)
    }

}

