


use WebService::GitHub::Role;

class WebService::GitHub::Repos::Releases  {
    also does WebService::GitHub::Role;
    method create-release(Str $owner, Str $repo, Str :$tag-name!, Str :$body, Bool :$prerelease, Str :$name, Str :$target-commitish, Bool :$draft) {
        my %data;
        %data<body> = $body if defined $body;
        %data<prerelease> = $prerelease if defined $prerelease;
        %data<name> = $name if defined $name;
        %data<target_commitish> = $target-commitish if defined $target-commitish;
        %data<tag_name> = $tag-name;
        %data<draft> = $draft if defined $draft;
        self.request("/repos/$owner/$repo/releases","POST", :%data)
    }

    method delete-release(Str $owner, Str $repo, Int(Str) $release-id) {
        self.request("/repos/$owner/$repo/releases/$release-id","DELETE")
    }

    method delete-release-asset(Str $owner, Str $repo, Int(Str) $asset-id) {
        self.request("/repos/$owner/$repo/releases/assets/$asset-id","DELETE")
    }

    method get-latest-release(Str $owner, Str $repo) {
        self.request("/repos/$owner/$repo/releases/latest","GET")
    }

    method get-release(Str $owner, Str $repo, Int(Str) $release-id) {
        self.request("/repos/$owner/$repo/releases/$release-id","GET")
    }

    method get-release-asset(Str $owner, Str $repo, Int(Str) $asset-id) {
        self.request("/repos/$owner/$repo/releases/assets/$asset-id","GET")
    }

    method get-release-by-tag(Str $owner, Str $repo, Str $tag) {
        self.request("/repos/$owner/$repo/releases/tags/$tag","GET")
    }

    method list-release-assets(Str $owner, Str $repo, Int(Str) $release-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/releases/$release-id/assets","GET", :%data)
    }

    method list-releases(Str $owner, Str $repo, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/repos/$owner/$repo/releases","GET", :%data)
    }

    method update-release(Str $owner, Str $repo, Int(Str) $release-id, Bool :$prerelease, Str :$body, Str :$target-commitish, Bool :$draft, Str :$name, Str :$tag-name) {
        my %data;
        %data<prerelease> = $prerelease if defined $prerelease;
        %data<body> = $body if defined $body;
        %data<target_commitish> = $target-commitish if defined $target-commitish;
        %data<draft> = $draft if defined $draft;
        %data<name> = $name if defined $name;
        %data<tag_name> = $tag-name if defined $tag-name;
        self.request("/repos/$owner/$repo/releases/$release-id","PATCH", :%data)
    }

    method update-release-asset(Str $owner, Str $repo, Int(Str) $asset-id, Str :$label, Str :$name, Str :$state) {
        my %data;
        %data<label> = $label if defined $label;
        %data<name> = $name if defined $name;
        %data<state> = $state if defined $state;
        self.request("/repos/$owner/$repo/releases/assets/$asset-id","PATCH", :%data)
    }

    method upload-release-asset(Str $owner, Str $repo, Int(Str) $release-id, Str :$name, Str :$label) {
        my %data;
        %data<name> = $name if defined $name;
        %data<label> = $label if defined $label;
        self.request("/repos/$owner/$repo/releases/$release-id/assets","POST", :%data)
    }

}

