

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Search::CodeOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::CodeOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::CodeSort of Str where subset-is * eq 'indexed', 'WebService::GitHub::Search::CodeSort must be either "indexed"';

subset WebService::GitHub::Search::CommitsOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::CommitsOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::CommitsSort of Str where subset-is * eq 'author-date'|'committer-date', 'WebService::GitHub::Search::CommitsSort must be either "author-date" or "committer-date"';

subset WebService::GitHub::Search::IssuesAndPullRequestsOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::IssuesAndPullRequestsOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::IssuesAndPullRequestsSort of Str where subset-is * eq 'comments'|'reactions'|'reactions-+1'|'reactions--1'|'reactions-smile'|'reactions-thinking_face'|'reactions-heart'|'reactions-tada'|'interactions'|'created'|'updated', 'WebService::GitHub::Search::IssuesAndPullRequestsSort must be either "comments", "reactions", "reactions-+1", "reactions--1", "reactions-smile", "reactions-thinking_face", "reactions-heart", "reactions-tada", "interactions", "created" or "updated"';

subset WebService::GitHub::Search::LabelsOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::LabelsOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::LabelsSort of Str where subset-is * eq 'created'|'updated', 'WebService::GitHub::Search::LabelsSort must be either "created" or "updated"';

subset WebService::GitHub::Search::ReposOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::ReposOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::ReposSort of Str where subset-is * eq 'stars'|'forks'|'help-wanted-issues'|'updated', 'WebService::GitHub::Search::ReposSort must be either "stars", "forks", "help-wanted-issues" or "updated"';

subset WebService::GitHub::Search::UsersOrder of Str where subset-is * eq 'desc'|'asc', 'WebService::GitHub::Search::UsersOrder must be either "desc" or "asc"';

subset WebService::GitHub::Search::UsersSort of Str where subset-is * eq 'followers'|'repositories'|'joined', 'WebService::GitHub::Search::UsersSort must be either "followers", "repositories" or "joined"';


class WebService::GitHub::Search  {
    also does WebService::GitHub::Role;
    method code(Str $q, WebService::GitHub::Search::CodeSort :$sort, WebService::GitHub::Search::CodeOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/search/code","GET", :%data)
    }

    method commits(Str $q, WebService::GitHub::Search::CommitsSort :$sort, WebService::GitHub::Search::CommitsOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/search/commits","GET", :%data)
    }

    method issues-and-pull-requests(Str $q, WebService::GitHub::Search::IssuesAndPullRequestsSort :$sort, WebService::GitHub::Search::IssuesAndPullRequestsOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/search/issues","GET", :%data)
    }

    method labels(Int(Str) $repository-id, Str $q, WebService::GitHub::Search::LabelsSort :$sort, WebService::GitHub::Search::LabelsOrder :$order) {
        my %data;
        %data<repository_id> = $repository-id;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        self.request("/search/labels","GET", :%data)
    }

    method repos(Str $q, WebService::GitHub::Search::ReposSort :$sort, WebService::GitHub::Search::ReposOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/search/repositories","GET", :%data)
    }

    method topics(Str $q) {
        my %data;
        %data<q> = $q;
        self.request("/search/topics","GET", :%data)
    }

    method users(Str $q, WebService::GitHub::Search::UsersSort :$sort, WebService::GitHub::Search::UsersOrder :$order, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<q> = $q;
        %data<sort> = $sort if defined $sort;
        %data<order> = $order if defined $order;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/search/users","GET", :%data)
    }

}

