

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Teams::AddOrUpdateProjectPermissionsInOrgPermission of Str where subset-is * eq 'read'|'write'|'admin', 'WebService::GitHub::Teams::AddOrUpdateProjectPermissionsInOrgPermission must be either "read", "write" or "admin"';

subset WebService::GitHub::Teams::AddOrUpdateProjectPermissionsLegacyPermission of Str where subset-is * eq 'read'|'write'|'admin', 'WebService::GitHub::Teams::AddOrUpdateProjectPermissionsLegacyPermission must be either "read", "write" or "admin"';

subset WebService::GitHub::Teams::AddOrUpdateRepoPermissionsInOrgPermission of Str where subset-is * eq 'pull'|'push'|'admin'|'maintain'|'triage', 'WebService::GitHub::Teams::AddOrUpdateRepoPermissionsInOrgPermission must be either "pull", "push", "admin", "maintain" or "triage"';

subset WebService::GitHub::Teams::AddOrUpdateRepoPermissionsLegacyPermission of Str where subset-is * eq 'pull'|'push'|'admin', 'WebService::GitHub::Teams::AddOrUpdateRepoPermissionsLegacyPermission must be either "pull", "push" or "admin"';

subset WebService::GitHub::Teams::CreatePermission of Str where subset-is * eq 'pull'|'push'|'admin', 'WebService::GitHub::Teams::CreatePermission must be either "pull", "push" or "admin"';

subset WebService::GitHub::Teams::CreatePrivacy of Str where subset-is * eq 'secret'|'closed', 'WebService::GitHub::Teams::CreatePrivacy must be either "secret" or "closed"';

subset WebService::GitHub::Teams::UpdateInOrgPermission of Str where subset-is * eq 'pull'|'push'|'admin', 'WebService::GitHub::Teams::UpdateInOrgPermission must be either "pull", "push" or "admin"';

subset WebService::GitHub::Teams::UpdateInOrgPrivacy of Str where subset-is * eq 'secret'|'closed', 'WebService::GitHub::Teams::UpdateInOrgPrivacy must be either "secret" or "closed"';

subset WebService::GitHub::Teams::UpdateLegacyPermission of Str where subset-is * eq 'pull'|'push'|'admin', 'WebService::GitHub::Teams::UpdateLegacyPermission must be either "pull", "push" or "admin"';

subset WebService::GitHub::Teams::UpdateLegacyPrivacy of Str where subset-is * eq 'secret'|'closed', 'WebService::GitHub::Teams::UpdateLegacyPrivacy must be either "secret" or "closed"';


class WebService::GitHub::Teams  {
    also does WebService::GitHub::Role;
    method add-or-update-project-permissions-in-org(Str $org, Str $team-slug, Int(Str) $project-id, WebService::GitHub::Teams::AddOrUpdateProjectPermissionsInOrgPermission :$permission) {
        my %data;
        %data<permission> = $permission if defined $permission;
        self.request("/orgs/$org/teams/$team-slug/projects/$project-id","PUT", :%data)
    }

    method add-or-update-project-permissions-legacy(Int(Str) $team-id, Int(Str) $project-id, WebService::GitHub::Teams::AddOrUpdateProjectPermissionsLegacyPermission :$permission) {
        my %data;
        %data<permission> = $permission if defined $permission;
        self.request("/teams/$team-id/projects/$project-id","PUT", :%data)
    }

    method add-or-update-repo-permissions-in-org(Str $org, Str $team-slug, Str $owner, Str $repo, WebService::GitHub::Teams::AddOrUpdateRepoPermissionsInOrgPermission :$permission) {
        my %data;
        %data<permission> = $permission if defined $permission;
        self.request("/orgs/$org/teams/$team-slug/repos/$owner/$repo","PUT", :%data)
    }

    method add-or-update-repo-permissions-legacy(Int(Str) $team-id, Str $owner, Str $repo, WebService::GitHub::Teams::AddOrUpdateRepoPermissionsLegacyPermission :$permission) {
        my %data;
        %data<permission> = $permission if defined $permission;
        self.request("/teams/$team-id/repos/$owner/$repo","PUT", :%data)
    }

    method check-permissions-for-project-in-org(Str $org, Str $team-slug, Int(Str) $project-id) {
        self.request("/orgs/$org/teams/$team-slug/projects/$project-id","GET")
    }

    method check-permissions-for-project-legacy(Int(Str) $team-id, Int(Str) $project-id) {
        self.request("/teams/$team-id/projects/$project-id","GET")
    }

    method check-permissions-for-repo-in-org(Str $org, Str $team-slug, Str $owner, Str $repo) {
        self.request("/orgs/$org/teams/$team-slug/repos/$owner/$repo","GET")
    }

    method check-permissions-for-repo-legacy(Int(Str) $team-id, Str $owner, Str $repo) {
        self.request("/teams/$team-id/repos/$owner/$repo","GET")
    }

    method create(Str $org, Str :$name!, Str :$description, Int(Str) :$parent-team-id, Positional :$maintainers, WebService::GitHub::Teams::CreatePermission :$permission, WebService::GitHub::Teams::CreatePrivacy :$privacy, Positional :$repo-names) {
        my %data;
        %data<description> = $description if defined $description;
        %data<name> = $name;
        %data<parent_team_id> = $parent-team-id if defined $parent-team-id;
        %data<maintainers> = $maintainers if defined $maintainers;
        %data<permission> = $permission if defined $permission;
        %data<privacy> = $privacy if defined $privacy;
        %data<repo_names> = $repo-names if defined $repo-names;
        self.request("/orgs/$org/teams","POST", :%data)
    }

    method delete-in-org(Str $org, Str $team-slug) {
        self.request("/orgs/$org/teams/$team-slug","DELETE")
    }

    method delete-legacy(Int(Str) $team-id) {
        self.request("/teams/$team-id","DELETE")
    }

    method get-by-name(Str $org, Str $team-slug) {
        self.request("/orgs/$org/teams/$team-slug","GET")
    }

    method get-legacy(Int(Str) $team-id) {
        self.request("/teams/$team-id","GET")
    }

    method list(Str $org, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/teams","GET", :%data)
    }

    method list-child-in-org(Str $org, Str $team-slug, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/teams/$team-slug/teams","GET", :%data)
    }

    method list-child-legacy(Int(Str) $team-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/teams/$team-id/teams","GET", :%data)
    }

    method list-for-authenticated-user(Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/user/teams","GET", :%data)
    }

    method list-projects-in-org(Str $org, Str $team-slug, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/teams/$team-slug/projects","GET", :%data)
    }

    method list-projects-legacy(Int(Str) $team-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/teams/$team-id/projects","GET", :%data)
    }

    method list-repos-in-org(Str $org, Str $team-slug, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/orgs/$org/teams/$team-slug/repos","GET", :%data)
    }

    method list-repos-legacy(Int(Str) $team-id, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/teams/$team-id/repos","GET", :%data)
    }

    method remove-project-in-org(Str $org, Str $team-slug, Int(Str) $project-id) {
        self.request("/orgs/$org/teams/$team-slug/projects/$project-id","DELETE")
    }

    method remove-project-legacy(Int(Str) $team-id, Int(Str) $project-id) {
        self.request("/teams/$team-id/projects/$project-id","DELETE")
    }

    method remove-repo-in-org(Str $org, Str $team-slug, Str $owner, Str $repo) {
        self.request("/orgs/$org/teams/$team-slug/repos/$owner/$repo","DELETE")
    }

    method remove-repo-legacy(Int(Str) $team-id, Str $owner, Str $repo) {
        self.request("/teams/$team-id/repos/$owner/$repo","DELETE")
    }

    method update-in-org(Str $org, Str $team-slug, WebService::GitHub::Teams::UpdateInOrgPermission :$permission, Int(Str) :$parent-team-id, Str :$name, WebService::GitHub::Teams::UpdateInOrgPrivacy :$privacy, Str :$description) {
        my %data;
        %data<permission> = $permission if defined $permission;
        %data<parent_team_id> = $parent-team-id if defined $parent-team-id;
        %data<name> = $name if defined $name;
        %data<privacy> = $privacy if defined $privacy;
        %data<description> = $description if defined $description;
        self.request("/orgs/$org/teams/$team-slug","PATCH", :%data)
    }

    method update-legacy(Int(Str) $team-id, Str :$name!, Int(Str) :$parent-team-id, Str :$description, WebService::GitHub::Teams::UpdateLegacyPrivacy :$privacy, WebService::GitHub::Teams::UpdateLegacyPermission :$permission) {
        my %data;
        %data<name> = $name;
        %data<parent_team_id> = $parent-team-id if defined $parent-team-id;
        %data<description> = $description if defined $description;
        %data<privacy> = $privacy if defined $privacy;
        %data<permission> = $permission if defined $permission;
        self.request("/teams/$team-id","PATCH", :%data)
    }

}

