

use Subset::Helper;
use WebService::GitHub::Role;
subset WebService::GitHub::Teams::Discussions::ListDiscussionsInOrgDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Teams::Discussions::ListDiscussionsInOrgDirection must be either "asc" or "desc"';

subset WebService::GitHub::Teams::Discussions::ListDiscussionsLegacyDirection of Str where subset-is * eq 'asc'|'desc', 'WebService::GitHub::Teams::Discussions::ListDiscussionsLegacyDirection must be either "asc" or "desc"';


class WebService::GitHub::Teams::Discussions  {
    also does WebService::GitHub::Role;
    method create-discussion-in-org(Str $org, Str $team-slug, Str :$title!, Str :$body!, Bool :$private) {
        my %data;
        %data<private> = $private if defined $private;
        %data<title> = $title;
        %data<body> = $body;
        self.request("/orgs/$org/teams/$team-slug/discussions","POST", :%data)
    }

    method create-discussion-legacy(Int(Str) $team-id, Str :$body!, Str :$title!, Bool :$private) {
        my %data;
        %data<body> = $body;
        %data<private> = $private if defined $private;
        %data<title> = $title;
        self.request("/teams/$team-id/discussions","POST", :%data)
    }

    method delete-discussion-in-org(Str $org, Str $team-slug, Int(Str) $discussion-number) {
        self.request("/orgs/$org/teams/$team-slug/discussions/$discussion-number","DELETE")
    }

    method delete-discussion-legacy(Int(Str) $team-id, Int(Str) $discussion-number) {
        self.request("/teams/$team-id/discussions/$discussion-number","DELETE")
    }

    method get-discussion-in-org(Str $org, Str $team-slug, Int(Str) $discussion-number) {
        self.request("/orgs/$org/teams/$team-slug/discussions/$discussion-number","GET")
    }

    method get-discussion-legacy(Int(Str) $team-id, Int(Str) $discussion-number) {
        self.request("/teams/$team-id/discussions/$discussion-number","GET")
    }

    method list-discussions-in-org(Str $org, Str $team-slug, WebService::GitHub::Teams::Discussions::ListDiscussionsInOrgDirection :$direction, Int(Str) :$per-page, Int(Str) :$page, Str :$pinned) {
        my %data;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        %data<pinned> = $pinned if defined $pinned;
        self.request("/orgs/$org/teams/$team-slug/discussions","GET", :%data)
    }

    method list-discussions-legacy(Int(Str) $team-id, WebService::GitHub::Teams::Discussions::ListDiscussionsLegacyDirection :$direction, Int(Str) :$per-page, Int(Str) :$page) {
        my %data;
        %data<direction> = $direction if defined $direction;
        %data<per_page> = $per-page if defined $per-page;
        %data<page> = $page if defined $page;
        self.request("/teams/$team-id/discussions","GET", :%data)
    }

    method update-discussion-in-org(Str $org, Str $team-slug, Int(Str) $discussion-number, Str :$body, Str :$title) {
        my %data;
        %data<body> = $body if defined $body;
        %data<title> = $title if defined $title;
        self.request("/orgs/$org/teams/$team-slug/discussions/$discussion-number","PATCH", :%data)
    }

    method update-discussion-legacy(Int(Str) $team-id, Int(Str) $discussion-number, Str :$body, Str :$title) {
        my %data;
        %data<body> = $body if defined $body;
        %data<title> = $title if defined $title;
        self.request("/teams/$team-id/discussions/$discussion-number","PATCH", :%data)
    }

}

